#!/usr/bin/env python
# -*- coding: UTF-8 -*-

import pygtk
pygtk.require('2.0')
import gtk, pango
import gobject
import egg.trayicon
import webbrowser
import gammu
import datetime, time
import gettext
import os


#######################################################################
#
#   Main informations about the software
#

__fullname__ = "Pammu®"
__version__ = "v0.15b-dev"
__date__ = "22-04-2009"
__author__ = "Marton S. Viktor"
__email__ = "msv@titok.info"
__helpurl__ = "http://titok.info/pammu/"
__phonedatabaseurl__ = "http://cihar.com/gammu/phonedb/"
__errorurl__ = "https://bugs.launchpad.net/pammu"
__launchpadurl__ = "https://launchpad.net/pammu"

__about__ = """
Free mobil device manager software
under GPL license. It uses Gammu
as interface to phone.

Author: %s
E-mail: %s
""" % (__author__, __email__)

__license__ = """

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
MA 02110-1301, USA.
"""

# for POT creation:
#   _("Location") _("Date") _("Text") _("Type") _("Priority") _("Completed") _("Number")
#   _("StartDate") _("EndDate") _("CallLength") _("Mobile")

LISTS = {
    'CALENDAR': {
        'STORE': None, 'PAGE': 0,
        'FIELDS': [ 'Location', 'Type', 'Priority', 'Completed', 'StartDate','EndDate', 'Text' ],
        'WIDTHS': [  0,          0,      0,          0,           80,         0,         80,   ],
        'TYPES':  [  0,       -1, ['Low','Medium','High'], ['yes','no'], 1,   1,         1     ],
        'DEFS':   [  '0',       'MEETING', 'Medium', 'no',       '_NOW_',    '_NOW_',   ''     ],
        'COMMANDS': { 'GETNEXT': 'GetNextCalendar', 'GETID': 'GetCalendar', 'STATUS': 'GetCalendarStatus',
                    'DEL': 'DeleteCalendar', 'ADD': 'AddCalendar', 'SET': 'SetCalendar' }
    },
    'TODO': {
        'STORE': None, 'PAGE': 0,
        'FIELDS': [ 'Location', 'Type', 'Priority', 'Completed', 'EndDate', 'Text' ],
        'WIDTHS': [  20,         0,      50,         40,          60,     80    ],
        'TYPES':  [  0,     -1, ['Low','Medium','High'], ['yes','no'], 1, 1     ],
        'DEFS':   [  '0',    'MEMO',    'Medium',     'no',    '_NOW_',   ''    ],
        'COMMANDS': { 'GETNEXT': 'GetNextToDo', 'GETID': 'GetToDo', 'STATUS': 'GetToDoStatus',
                    'DEL': 'DeleteToDo', 'ADD': 'AddToDo', 'SET': 'SetToDo' }
    },
    'CALL': {
        'STORE': None, 'PAGE': 0,
        'FIELDS': [ 'Location', 'Type', 'Name', 'Number', 'Date', 'CallLength' ],
        'WIDTHS': [  0,          20,     100,    100,      40,     40          ],
        'TYPES':  [  0,  ['DC','RC','MC'], 1,    1,        1,      1           ],
        'DEFS':   [  '0',       'DC',    '',     '',      '_NOW_', '0'         ],
        'COMMANDS': { 'GETNEXT': 'GetNextMemory', 'GETID': 'GetMemory', 'STATUS': 'GetMemoryStatus',
                    'DEL': 'DeleteMemory', 'ADD': 'AddMemory', 'SET': 'SetMemory' }
    },
    'CONTACT': {
        'STORE': None, 'PAGE': 0,
        'FIELDS': [ 'Location', 'Type', 'Name', 'Number' ],
        'WIDTHS': [  20,         0,      100,   40       ],
        'TYPES':  [  0,     ['SM','ME'], 1,     1        ],
        'DEFS':   [  '0',    'ME',       '',    '',      ],
        'COMMANDS': { 'GETNEXT': 'GetNextMemory', 'GETID': 'GetMemory', 'STATUS': 'GetMemoryStatus',
                    'DEL': 'DeleteMemory', 'ADD': 'AddMemory', 'SET': 'SetMemory' }
    },
    'SMS': {
        'STORE': None, 'PAGE': 0,
        'FIELDS': [ 'Location', 'Name', 'Number', 'Text' ],
        'WIDTHS': [  20,         0,      100,      10    ],
        'TYPES':  [  0,          1,      1,        1     ],
        'DEFS':   [  '0',       '',     '',       ''     ],
        'COMMANDS': { 'GETNEXT': 'GetNextSMS', 'GETID': 'GetSMS', 'STATUS': 'GetSMSStatus',
                    'DEL': 'DeleteSMS', 'ADD': 'AddSMS', 'SET': 'SetSMS' }
    }
}

DATATYPE = {
    'MEETING':  { 'TABLE': 'CALENDAR', 'PBAR': None },
    'MEMO':     { 'TABLE': 'TODO',     'PBAR': None },
    'SM':       { 'TABLE': 'CONTACT',  'PBAR': None },
    'ME':       { 'TABLE': 'CONTACT',  'PBAR': None },
    'ON':       { 'TABLE': 'CALL',     'PBAR': None },
    'DC':       { 'TABLE': 'CALL',     'PBAR': None },
    'RC':       { 'TABLE': 'CALL',     'PBAR': None },
    'MC':       { 'TABLE': 'CALL',     'PBAR': None },
    'MT':       { 'TABLE': 'SMS',      'PBAR': None },
    'FD':       { 'TABLE': 'SMS',      'PBAR': None },
    'ON':       { 'TABLE': 'SMS',      'PBAR': None },
    'VM':       { 'TABLE': 'SMS',      'PBAR': None }
}

DEF_CFG = {
    'StartInfo': 'yes',
    'UseGlobalDebugFile': 1,
    'DebugFile': None,
    'SyncTime': 'yes',
    'Connection': 'bluerfphonet',
    'LockDevice': 'no',
    'DebugLevel': 'textalldate',
    'Device': '00:24:7d:d7:ac:60',
    'Localize': None,
    'Model': '',
}

RET_OK      = 0
RET_CANCEL  = 1
RET_DELETE  = 2

CONNECTION_TYPES = (
    'at19200',
    'at115200',
    'blueat',
    'bluefbus',
    'blueobex',
    'bluephonet',
    'bluerfgnapbus',
    'bluerfphonet',
    'fbus',
    'fbuspl2303',
    'fbusblue',
    'fbusdlr3',
    'irdaat',
    'irdaphonet',
    'mbus',
    'obex',
    'phonetblue'
)

CONNECTION_MODELS = (
    'auto',
    'at',
    'alcatel',
    'nauto',
    'obex',
    'seobex'
)

CONNECTION_PORTS_WIN = (
    'com1:',
    'com2:',
    'com3:',
    'com4:'
)

CONNECTION_PORTS_LIN = (
    '/dev/ttyS0',
    '/dev/ttyS1',
    '/dev/ttyUSB0',
    '/dev/ttyUSB1',
    '/dev/ttyACM0',
    '/dev/ttyACM1',
    '/dev/ircomm0',
    '/dev/rfcomm0',
    '/dev/usb/tts/0'
)

XPM = {
    'MOBILE': ["81 180 1859 2","  	c None",". 	c #424242","+ 	c #0C0C0C","@ 	c #0D0D0D","# 	c #0B0B0B","$ 	c #656565","% 	c #414141","& 	c #000000","* 	c #7A7A7A","= 	c #010101","- 	c #707070","; 	c #8C8C8C","> 	c #383838",", 	c #262F42","' 	c #636DA0",") 	c #6670A4","! 	c #6873A7","~ 	c #10111A","{ 	c #393939","] 	c #131313","^ 	c #2B2F47","/ 	c #6A73A5","( 	c #6A73A4","_ 	c #6B74A5",": 	c #273247","< 	c #070707","[ 	c #3E4567","} 	c #495176","| 	c #484F76","1 	c #525A86","2 	c #E8E8E8","3 	c #566092","4 	c #57618C","5 	c #C5C5C5","6 	c #5A6393","7 	c #57608D","8 	c #ADADAD","9 	c #5C6796","0 	c #6A72A4","a 	c #565F8C","b 	c #939393","c 	c #5E6998","d 	c #6973A3","e 	c #59618E","f 	c #797979","g 	c #616A9A","h 	c #58628F","i 	c #050507","j 	c #616161","k 	c #636C9C","l 	c #59628E","m 	c #0B0B16","n 	c #9B9B9B","o 	c #474747","p 	c #656E9E","q 	c #5B6392","r 	c #0E0D13","s 	c #AFAFAF","t 	c #323232","u 	c #00002F","v 	c #66709F","w 	c #6972A3","x 	c #5D6594","y 	c #0C0F16","z 	c #A7A7A7","A 	c #464646","B 	c #282F41","C 	c #666F9F","D 	c #5E6798","E 	c #0D0F16","F 	c #9E9E9E","G 	c #404040","H 	c #272D41","I 	c #6770A1","J 	c #5F6899","K 	c #0E0F17","L 	c #969696","M 	c #373737","N 	c #292C43","O 	c #616A9D","P 	c #0E1017","Q 	c #8E8E8E","R 	c #2F2F2F","S 	c #2A3247","T 	c #6871A2","U 	c #636D9F","V 	c #0E0F18","W 	c #868686","X 	c #262626","Y 	c #2D314A","Z 	c #6972A4","` 	c #656FA3"," .	c #0E1018","..	c #7D7D7D","+.	c #191919","@.	c #282B4A","#.	c #46577B","$.	c #2A3047","%.	c #485179","&.	c #4B537F","*.	c #4F5884","=.	c #58618E","-.	c #5D6795",";.	c #616B9E",">.	c #0F1118",",.	c #757575","'.	c #0A0A0A",").	c #0F0F16","!.	c #181926","~.	c #05090C","{.	c #676767","].	c #151515","^.	c #CECECE","/.	c #5D5D5D","(.	c #E2E2E2","_.	c #191A1C",":.	c #646C7C","<.	c #767F90","[.	c #7F899C","}.	c #8891A3","|.	c #8992A5","1.	c #8B94A6","2.	c #8690A3","3.	c #808B9E","4.	c #7B8496","5.	c #70798A","6.	c #676D7C","7.	c #565C6E","8.	c #272A32","9.	c #040606","0.	c #F8F8F8","a.	c #EEEEEE","b.	c #E3E3E3","c.	c #D9D9D9","d.	c #CDCDCD","e.	c #C2C2C2","f.	c #B8B8B8","g.	c #AEAEAE","h.	c #8D8D8D","i.	c #7C7C7C","j.	c #6C6C6C","k.	c #5C5C5C","l.	c #808080","m.	c #909090","n.	c #929292","o.	c #919191","p.	c #8F8F8F","q.	c #8A8A8A","r.	c #898989","s.	c #878787","t.	c #858585","u.	c #848484","v.	c #828282","w.	c #818181","x.	c #7F7F7F","y.	c #2C2C2C","z.	c #1B1F23","A.	c #2C3038","B.	c #30353E","C.	c #353943","D.	c #373C45","E.	c #5E6271","F.	c #606778","G.	c #6B7283","H.	c #70788A","I.	c #767F91","J.	c #778091","K.	c #7B8396","L.	c #7E879A","M.	c #7D889B","N.	c #6E7786","O.	c #20212A","P.	c #F0F0F0","Q.	c #BBBBBB","R.	c #505050","S.	c #4E4E4E","T.	c #444444","U.	c #303030","V.	c #292929","W.	c #212121","X.	c #0F0F0F","Y.	c #030303","Z.	c #171622","`.	c #1A1E22"," +	c #1D1F24",".+	c #1F2227","++	c #222526","@+	c #222343","#+	c #585858","$+	c #1A1A1A","%+	c #141927","&+	c #171929","*+	c #191D2E","=+	c #1A1E31","-+	c #1E2233",";+	c #212436",">+	c #292E44",",+	c #454867","'+	c #484C6B",")+	c #495373","!+	c #505375","~+	c #53597B","{+	c #5A5F7C","]+	c #5F6581","^+	c #636885","/+	c #666D8A","(+	c #69728E","_+	c #6E7593",":+	c #727896","<+	c #767A9B","[+	c #787FA0","}+	c #7C83A4","|+	c #7F86A9","1+	c #8288AD","2+	c #838AAB","3+	c #858CAE","4+	c #878DB0","5+	c #898FB2","6+	c #8B91B3","7+	c #8B91B4","8+	c #8B92B4","9+	c #8B92B5","0+	c #888FB2","a+	c #848DB1","b+	c #8087AE","c+	c #7B83AC","d+	c #767FAC","e+	c #6D76A9","f+	c #6972A5","g+	c #6871A5","h+	c #6771A3","i+	c #656FA1","j+	c #646DA0","k+	c #636D9E","l+	c #60699A","m+	c #5C6593","n+	c #56608A","o+	c #555D87","p+	c #555C86","q+	c #4E5780","r+	c #454E74","s+	c #444A6B","t+	c #222639","u+	c #212537","v+	c #1A1D2A","w+	c #030208","x+	c #313751","y+	c #797E9B","z+	c #9EA2BA","A+	c #A5A8BA","B+	c #AAAEBE","C+	c #AFB3C2","D+	c #B4B8C6","E+	c #B6B9C9","F+	c #B7BACA","G+	c #B8BACA","H+	c #B8BBCB","I+	c #B8BCCB","J+	c #BABDCC","K+	c #BBBECC","L+	c #BCC0CE","M+	c #BABCCB","N+	c #B7BAC9","O+	c #B6BAC9","P+	c #B5B8C8","Q+	c #B4B7C6","R+	c #B1B4C5","S+	c #ADB0C1","T+	c #AAADBE","U+	c #A6AABC","V+	c #A2A6BB","W+	c #9EA2B9","X+	c #999EB9","Y+	c #9399B7","Z+	c #8E94B5","`+	c #8A90B2"," @	c #868DAF",".@	c #8288AC","+@	c #7F86AA","@@	c #7A81A7","#@	c #747CA5","$@	c #727AA4","%@	c #7078A4","&@	c #6D76A4","*@	c #6B74A4","=@	c #6B74A6","-@	c #6C75A6",";@	c #6670A3",">@	c #060609",",@	c #060523","'@	c #686F94",")@	c #B8BBCA","!@	c #B9BCCB","~@	c #BABDCB","{@	c #B6B9C8","]@	c #A8ACBE","^@	c #9BA0B8","/@	c #8F94B3","(@	c #838AAC","_@	c #777EA5",":@	c #747CA4","<@	c #7078A3","[@	c #6D75A2","}@	c #6A72A2","|@	c #6770A2","1@	c #666FA2","2@	c #6770A3","3@	c #6871A3","4@	c #616A9B","5@	c #11141C","6@	c #525252","7@	c #888FB0","8@	c #B3B6C5","9@	c #9096B2","0@	c #7D84A8","a@	c #6972A2","b@	c #6772A5","c@	c #14151B","d@	c #565656","e@	c #1C1C1C","f@	c #364168","g@	c #ACB0C2","h@	c #898FAE","i@	c #656FA2","j@	c #6C75A7","k@	c #181B58","l@	c #2E2E2E","m@	c #47496B","n@	c #AEB2C4","o@	c #7178A3","p@	c #30334D","q@	c #141414","r@	c #565A78","s@	c #BBBECD","t@	c #B3B6C6","u@	c #6F77A2","v@	c #414D6E","w@	c #6A7090","x@	c #7C83A7","y@	c #484E72","z@	c #7D85AB","A@	c #A6ABBE","B@	c #4F557C","C@	c #7E7E7E","D@	c #10131D","E@	c #8B92B2","F@	c #8288A9","G@	c #6B73A5","H@	c #131522","I@	c #A1A4B9","J@	c #B1B4C4","K@	c #6973A5","L@	c #575F88","M@	c #2A2F48","N@	c #2B3048","O@	c #2A2E46","P@	c #292D45","Q@	c #282D43","R@	c #272C41","S@	c #262B3F","T@	c #252A3F","U@	c #24293C","V@	c #24283C","W@	c #24293D","X@	c #25293C","Y@	c #25293D","Z@	c #252A3E","`@	c #26293E"," #	c #262A3F",".#	c #272B3F","+#	c #262B40","@#	c #272B41","##	c #282C41","$#	c #272B42","%#	c #282C42","&#	c #292E43","*#	c #292D43","=#	c #292D44","-#	c #2A2E45",";#	c #2A2F46",">#	c #2C3048",",#	c #2C3148","'#	c #555C87",")#	c #5B6492","!#	c #343434","~#	c #131622","{#	c #B1B3C4","]#	c #9CA1BA","^#	c #080815","/#	c #505B86","(#	c #5F6898","_#	c #1F1F1F",":#	c #3B3D67","<#	c #848AAA","[#	c #424781","}#	c #2B2F46","|#	c #6872A4","1#	c #636EA0","2#	c #0E0E0E","3#	c #424B6D","4#	c #7079A3","5#	c #6A74A5","6#	c #30354C","7#	c #050505","8#	c #090808","9#	c #090909","0#	c #0C0B0B","a#	c #080808","b#	c #060606","c#	c #040404","d#	c #040303","e#	c #656E9F","f#	c #626C9E","g#	c #11131C","h#	c #696969","i#	c #4F5273","j#	c #B0B4C4","k#	c #6670A2","l#	c #242B3E","m#	c #7E7F7F","n#	c #4E4D4D","o#	c #5C6591","p#	c #646EA0","q#	c #12141C","r#	c #575E7C","s#	c #A8ACBF","t#	c #6A74A7","u#	c #0A0813","v#	c #828383","w#	c #838383","x#	c #727373","y#	c #414870","z#	c #656EA2","A#	c #13141F","B#	c #737373","C#	c #606787","D#	c #9DA2BC","E#	c #2D2C2C","F#	c #7B7B7B","G#	c #656464","H#	c #5A5959","I#	c #515151","J#	c #4C4C4C","K#	c #484747","L#	c #3E3E3E","M#	c #3A3939","N#	c #363636","O#	c #333333","P#	c #313131","Q#	c #2D2D2D","R#	c #2C2B2B","S#	c #2A2A2A","T#	c #2A2929","U#	c #282828","V#	c #2B2B2B","W#	c #3B3B3B","X#	c #3F3F3F","Y#	c #434343","Z#	c #5B5A5A","`#	c #646464"," $	c #6F6E6E",".$	c #787878","+$	c #2D324A","@$	c #151722","#$	c #636363","$$	c #707695","%$	c #8D93B1","&$	c #6A73A3","*$	c #616A99","=$	c #5A5A5A","-$	c #232323",";$	c #5F5E5E",">$	c #26293C",",$	c #161825","'$	c #545454",")$	c #AAAAAA","!$	c #7D84A7","~$	c #5A6491","{$	c #020202","]$	c #1A273D","^$	c #646D9C","/$	c #6872A6","($	c #181A27","_$	c #484848",":$	c #9D9D9D","<$	c #848BAE","[$	c #727BA4","}$	c #505884","|$	c #5B5B5B","1$	c #010201","2$	c #010301","3$	c #010401","4$	c #020402","5$	c #030503","6$	c #040604","7$	c #040704","8$	c #050805","9$	c #060906","0$	c #060907","a$	c #070A07","b$	c #080B08","c$	c #080A07","d$	c #070907","e$	c #060806","f$	c #050605","g$	c #040504","h$	c #020302","i$	c #000100","j$	c #5F6997","k$	c #6A73A6","l$	c #191B28","m$	c #8A91B3","n$	c #4A5075","o$	c #5F5F5F","p$	c #435743","q$	c #698669","r$	c #8FA38F","s$	c #95A995","t$	c #9CAF9C","u$	c #A0B3A0","v$	c #A3B6A2","w$	c #A5B9A5","x$	c #A7BAA7","y$	c #A6BAA6","z$	c #A7BBA7","A$	c #A7BBA6","B$	c #A7BCA6","C$	c #A7BCA7","D$	c #A7BDA6","E$	c #A6BDA6","F$	c #A6BCA5","G$	c #A5BCA4","H$	c #A2BCA2","I$	c #9FB99E","J$	c #9DB79C","K$	c #9AB499","L$	c #97B296","M$	c #94AF93","N$	c #91AC90","O$	c #8EA98C","P$	c #8AA689","Q$	c #829F82","R$	c #7C9A7C","S$	c #779476","T$	c #718F70","U$	c #6D8C6C","V$	c #678467","W$	c #5E795D","X$	c #546B53","Y$	c #4A5F49","Z$	c #3F523E","`$	c #324032"," %	c #646363",".%	c #56608D","+%	c #191C2A","@%	c #9198B7","#%	c #6C74A3","$%	c #2D324C","%%	c #668366","&%	c #89AA88","*%	c #C0D2C0","=%	c #BFD1BF","-%	c #C0D1C0",";%	c #C1D2C1",">%	c #C3D4C3",",%	c #BDCFBD","'%	c #B0C7B0",")%	c #A4BFA5","!%	c #9AB699","~%	c #90B090","{%	c #81A581","]%	c #80A480","^%	c #83A883","/%	c #283428","(%	c #777777","_%	c #3A4061",":%	c #181B56","<%	c #767676","[%	c #0F141B","}%	c #8F94B1","|%	c #121212","1%	c #6E8D6D","2%	c #99B699","3%	c #C2D5C2","4%	c #C4D7C4","5%	c #C8DAC8","6%	c #BCD2BB","7%	c #ACC7AB","8%	c #9CBA9B","9%	c #88AD88","0%	c #83AA83","a%	c #84AB85","b%	c #85AB85","c%	c #81A681","d%	c #7FA37F","e%	c #374636","f%	c #747474","g%	c #2E354E","h%	c #3C3F60","i%	c #666666","j%	c #10111D","k%	c #9096B0","l%	c #202535","m%	c #3D3D3D","n%	c #769876","o%	c #ABC2AA","p%	c #B3C1B3","q%	c #7E7F7E","r%	c #7F807F","s%	c #828382","t%	c #777877","u%	c #575757","v%	c #080908","w%	c #5C765B","x%	c #4A5F4A","y%	c #6A6A6A","z%	c #101010","A%	c #25283C","B%	c #6B75A6","C%	c #3A4467","D%	c #202020","E%	c #111421","F%	c #9297B0","G%	c #0C0B10","H%	c #242424","I%	c #333131","J%	c #050705","K%	c #7EA27D","L%	c #B7CAB7","M%	c #BACABA","N%	c #A4ADA4","O%	c #A5AEA5","P%	c #93A293","Q%	c #6C806A","R%	c #4F634D","S%	c #465B46","T%	c #495E48","U%	c #70906F","V%	c #617C60","W%	c #202335","X%	c #3B486A","Y%	c #161616","Z%	c #141724","`%	c #9296AF"," &	c #83A682",".&	c #BED1BE","+&	c #BFD1C0","@&	c #BDD0BD","#&	c #9FBA9F","$&	c #87A986","%&	c #7EA27E","&&	c #7FA47F","*&	c #759775","=&	c #1F2237","-&	c #3F456A",";&	c #161928",">&	c #9196B1",",&	c #626A99","'&	c #444343",")&	c #252525","!&	c #89AD89","~&	c #B9CDB9","{&	c #9CB79A","]&	c #7EA37E","^&	c #82A681","/&	c #606998","(&	c #404A6E","_&	c #272727",":&	c #181B2B","<&	c #9095B2","[&	c #5E6794","}&	c #212020","|&	c #0A0C09","1&	c #8CAF8C","2&	c #BED0BE","3&	c #9FB99F","4&	c #88AF88","5&	c #454545","6&	c #555F8E","7&	c #434B70","8&	c #1A1D2E","9&	c #9095B3","0&	c #5B648E","a&	c #1D1D1D","b&	c #0C100C","c&	c #8DB08D","d&	c #ACC3AC","e&	c #83A683","f&	c #87AD87","g&	c #3A3A3A","h&	c #727272","i&	c #4F5883","j&	c #444B73","k&	c #8E93B1","l&	c #555B88","m&	c #6F6F6F","n&	c #1B1919","o&	c #0D130D","p&	c #8EB08E","q&	c #99B598","r&	c #7FA37E","s&	c #86AC86","t&	c #40476B","u&	c #6B73A4","v&	c #454F75","w&	c #41446B","x&	c #4D557E","y&	c #0F120F","z&	c #92B291","A&	c #BBCEBB","B&	c #88A987","C&	c #85AB86","D&	c #070906","E&	c #2F364F","F&	c #484F78","G&	c #45486A","H&	c #8288AA","I&	c #444A76","J&	c #060505","K&	c #0F150F","L&	c #93B492","M&	c #B6CAB6","N&	c #7FA380","O&	c #080A08","P&	c #222222","Q&	c #4B517A","R&	c #474F6F","S&	c #7880A8","T&	c #373E5B","U&	c #181818","V&	c #B7CBB7","W&	c #85AA85","X&	c #090C09","Y&	c #1E1D1D","Z&	c #1F2135","`&	c #4C547D"," *	c #4B5173",".*	c #6F78A5","+*	c #292E45","@*	c #171717","#*	c #101610","$*	c #94B494","%*	c #BCCFBC","&*	c #85A784","**	c #84AA84","=*	c #0A0D0A","-*	c #1A1919",";*	c #6B75A8",">*	c #4F577E",",*	c #4D5376","'*	c #151414",")*	c #8FB18F","!*	c #8FAE8E","~*	c #84A984","{*	c #0C0F0B","]*	c #353434","^*	c #666EA0","/*	c #515981","(*	c #4B547A","_*	c #0D100D",":*	c #111111","<*	c #474646","[*	c #525C85","}*	c #4B547B","|*	c #242839","1*	c #1F1E1E","2*	c #0E120E","3*	c #0D110D","4*	c #111010","5*	c #555555","6*	c #5D6693","7*	c #555D89","8*	c #4D557F","9*	c #6670A1","0*	c #212538","a*	c #8BAE8B","b*	c #A6BFA6","c*	c #616060","d*	c #565F8D","e*	c #565E8A","f*	c #4E5782","g*	c #656FA0","h*	c #202634","i*	c #8AAE8A","j*	c #6B6B6B","k*	c #505883","l*	c #515984","m*	c #646E9E","n*	c #1E2032","o*	c #7DA27D","p*	c #0B0F0B","q*	c #4B537A","r*	c #58628E","s*	c #525985","t*	c #636D9D","u*	c #20262C","v*	c #84A983","w*	c #ADC3AC","x*	c #0B0E0B","y*	c #3B4163","z*	c #59638F","A*	c #535B86","B*	c #656E9C","C*	c #000025","D*	c #353535","E*	c #81A580","F*	c #95B394","G*	c #1B1A1A","H*	c #2D324B","I*	c #5B6391","J*	c #545B88","K*	c #626C9B","L*	c #7EA17D","M*	c #84A784","N*	c #5C6492","O*	c #555D88","P*	c #454444","Q*	c #373535","R*	c #7B9F7A","S*	c #161515","T*	c #6872A5","U*	c #5D6694","V*	c #565F8A","W*	c #5E6796","X*	c #4D4D4D","Y*	c #3B3A3A","Z*	c #789A78","`*	c #212336"," =	c #5E6696",".=	c #57608B","+=	c #5C6594","@=	c #565555","#=	c #403F3F","$=	c #030403","%=	c #769775","&=	c #88AE88","*=	c #222130","==	c #6771A4","-=	c #000017",";=	c #586087",">=	c #5B6491",",=	c #494949","'=	c #6F8E6E",")=	c #82A682","!=	c #82A782","~=	c #80A37F","{=	c #7D9F7C","]=	c #83A782","^=	c #4A4A4A","/=	c #6973A6","(=	c #5A6391","_=	c #5C5B5B",":=	c #678566","<=	c #7EA17E","[=	c #334233","}=	c #2F3C2F","|=	c #3C4E3C","1=	c #7B9E7A","2=	c #556F55","3=	c #6A8869","4=	c #606A9B","5=	c #0F0E1F","6=	c #565F89","7=	c #5B6390","8=	c #5E5D5D","9=	c #5D785D","0=	c #7DA17D","a=	c #232C22","b=	c #1E261E","c=	c #2F3C2E","d=	c #7FA27F","e=	c #5F795E","f=	c #759675","g=	c #506750","h=	c #646D9E","i=	c #979797","j=	c #04040A","k=	c #5A628E","l=	c #58618F","m=	c #2E3B2E","n=	c #647F63","o=	c #6B886B","p=	c #719171","q=	c #7C9F7B","r=	c #85AA84","s=	c #87AE87","t=	c #8AB18A","u=	c #89B089","v=	c #83A983","w=	c #324131","x=	c #636C9E","y=	c #9F9F9F","z=	c #13121C","A=	c #58618D","B=	c #636262","C=	c #0C0F0C","D=	c #101410","E=	c #141A14","F=	c #182018","G=	c #1C251C","H=	c #202A20","I=	c #242F23","J=	c #283328","K=	c #2D392C","L=	c #303E2F","M=	c #303E30","N=	c #313F30","O=	c #313F31","P=	c #324132","Q=	c #344333","R=	c #324031","S=	c #2F3D2F","T=	c #2D3A2D","U=	c #2B372B","V=	c #293529","W=	c #263226","X=	c #232E22","Y=	c #1C241C","Z=	c #141B14","`=	c #0D100C"," -	c #494848",".-	c #616998","+-	c #9C9C9C","@-	c #12111A","#-	c #58608D","$-	c #57628E","%-	c #606997","&-	c #646EA1","*-	c #999999","=-	c #58608B","--	c #676666",";-	c #606897",">-	c #959595",",-	c #686767","'-	c #535353",")-	c #292828","!-	c #262525","~-	c #050404","{-	c #100F0F","]-	c #1D1C1C","^-	c #3C3C3C","/-	c #4F4F4F","(-	c #5F6896","_-	c #575F8C",":-	c #535252","<-	c #080707","[-	c #5E6795","}-	c #6771A6","|-	c #575F8A","1-	c #56608B","2-	c #4B4B4B","3-	c #6873A8","4-	c #0E0D1D","5-	c #717171","6-	c #626B9B","7-	c #6975AA","8-	c #575F89","9-	c #545D8A","0-	c #686868","a-	c #6B76AB","b-	c #5E6694","c-	c #0D0C12","d-	c #1B1B1B","e-	c #292A2A","f-	c #252956","g-	c #6B77AC","h-	c #616B9D","i-	c #00002B","j-	c #525B80","k-	c #6B76AC","l-	c #05050C","m-	c #57608C","n-	c #2E304C","o-	c #000101","p-	c #5F5D5D","q-	c #2B2B4F","r-	c #1F2134","s-	c #0E0D29","t-	c #3B437E","u-	c #6C76AD","v-	c #373C5B","w-	c #232733","x-	c #191A29","y-	c #151B26","z-	c #161624","A-	c #1F2233","B-	c #495179","C-	c #626D9E","D-	c #4B5078","E-	c #171A26","F-	c #121126","G-	c #171621","H-	c #121225","I-	c #141924","J-	c #1B1D2C","K-	c #383B58","L-	c #0C0C14","M-	c #2E3452","N-	c #000016","O-	c #4C547B","P-	c #080814","Q-	c #504F4F","R-	c #080849","S-	c #5D6796","T-	c #6D76A8","U-	c #5C6797","V-	c #646C9C","W-	c #6A75A7","X-	c #5F6996","Y-	c #5D6794","Z-	c #676FA2","`-	c #020304"," ;	c #363535",".;	c #323955","+;	c #000019","@;	c #2D2F45","#;	c #0B0A0A","$;	c #15152A","%;	c #5E6897","&;	c #576191","*;	c #6B73A6","=;	c #4D567F","-;	c #000001",";;	c #3D3C3C",">;	c #5E5E5E",",;	c #727171","';	c #0C0D0D",");	c #1A1A28","!;	c #545E8C","~;	c #817D81","{;	c #827D81","];	c #5B659B","^;	c #4A5072","/;	c #7E7D7D","(;	c #0D0C0C","_;	c #2F2E2E",":;	c #626161","<;	c #1F1F32","[;	c #606B99","};	c #545D8B","|;	c #25D925","1;	c #12ED12","2;	c #37C637","3;	c #807F80","4;	c #525B87","5;	c #464B73","6;	c #000102","7;	c #464545","8;	c #6B6A6A","9;	c #202132","0;	c #56608E","a;	c #18E618","b;	c #01FF01","c;	c #1AE61A","d;	c #4C557F","e;	c #4A4F77","f;	c #100F17","g;	c #393B57","h;	c #1AE51A","i;	c #505983","j;	c #525D8A","k;	c #434C6C","l;	c #575656","m;	c #555454","n;	c #807F7F","o;	c #18E719","p;	c #00FF00","q;	c #1EE01E","r;	c #535C88","s;	c #616B9C","t;	c #1F1E2D","u;	c #21232F","v;	c #7B7A7A","w;	c #6F906D","x;	c #6A9569","y;	c #748B74","z;	c #5C6793","A;	c #404562","B;	c #080B11","C;	c #59618B","D;	c #545E89","E;	c #6E6E6E","F;	c #030507","G;	c #0A0B11","H;	c #5C6798","I;	c #11101A","J;	c #565F8B","K;	c #363B5A","L;	c #181717","M;	c #474F76","N;	c #4D5482","O;	c #6B76A9","P;	c #100F1B","Q;	c #232436","R;	c #595959","S;	c #333751","T;	c #3A3D61","U;	c #434141","V;	c #626262","W;	c #393F5D","X;	c #0E141D","Y;	c #5B6694","Z;	c #0C0E12","`;	c #010100"," >	c #3F4A69",".>	c #191818","+>	c #595858","@>	c #030202","#>	c #283752","$>	c #6670A0","%>	c #6974A7","&>	c #11101B","*>	c #4F5A82","=>	c #000028","->	c #373636",";>	c #393D68",">>	c #393F60",",>	c #12141F","'>	c #191A27",")>	c #6A73A7","!>	c #10141C","~>	c #545D88","{>	c #3E4561","]>	c #030406","^>	c #586190","/>	c #626B9E","(>	c #2B2929","_>	c #535D89",":>	c #6974A5","<>	c #373B60","[>	c #6D6D6D","}>	c #1F1F37","|>	c #5F699A","1>	c #6973A7","2>	c #3B4061","3>	c #404466","4>	c #151627","5>	c #232121","6>	c #121111","7>	c #151824","8>	c #555F8B","9>	c #656EA1","0>	c #1E2331","a>	c #0E0F16","b>	c #10121D","c>	c #525B85","d>	c #6872A3","e>	c #3C4365","f>	c #666565","g>	c #05060A","h>	c #626C9D","i>	c #42466B","j>	c #191C29","k>	c #100F22","l>	c #394967","m>	c #545D87","n>	c #6771A5","o>	c #222738","p>	c #2C2E4E","q>	c #606999","r>	c #11141D","s>	c #6973A4","t>	c #454D71","u>	c #0F0F19","v>	c #15202B","w>	c #5B6594","x>	c #2E348F","y>	c #272C42","z>	c #202336","A>	c #1E2132","B>	c #1F2333","C>	c #202436","D>	c #222538","E>	c #2F344E","F>	c #505A83","G>	c #6871A4","H>	c #4C5179","I>	c #181928","J>	c #3B3F5B","K>	c #646FA0","L>	c #4F5880","M>	c #5F6796","N>	c #484F74","O>	c #000031","P>	c #09090E","Q>	c #494E76","R>	c #5B6490","S>	c #626B9C","T>	c #6972A6","U>	c #6B74A7","V>	c #666FA1","W>	c #5E6693","X>	c #59618C","Y>	c #575E88","Z>	c #535A85","`>	c #4E5682"," ,	c #4F5783",".,	c #515B85","+,	c #555C85","@,	c #565E89","#,	c #58618C","$,	c #6A75A6","%,	c #6A74A6","&,	c #6A73A9","*,	c #5A6493","=,	c #1C1F2F","-,	c #1C2131",";,	c #393D5D",">,	c #545E8B",",,	c #6973A8","',	c #10131E","),	c #4C537E","!,	c #1B1F2D","~,	c #121D27","{,	c #424769","],	c #3F446C","^,	c #181A28","/,	c #5F6998","(,	c #4B4F7B","_,	c #1E2232",":,	c #191C28","<,	c #161827","[,	c #1B1E2E","},	c #464D73","|,	c #4C537D","1,	c #646D9D","2,	c #1B1D34","3,	c #141313","4,	c #020204","5,	c #596294","6,	c #4F5985","7,	c #131212","8,	c #31344D","9,	c #3E405E","0,	c #020101","a,	c #10141D","b,	c #010000","c,	c #737272","d,	c #464B71","e,	c #383F5F","f,	c #606B9C","g,	c #030407","h,	c #6E6D6D","i,	c #605F5F","j,	c #606060","k,	c #282E43","l,	c #48517A","m,	c #565E88","n,	c #1C2436","o,	c #2E3044","p,	c #586293","q,	c #040508","r,	c #7A7979","s,	c #1D2736","t,	c #6770A4","u,	c #485076","v,	c #444A7A","w,	c #838484","x,	c #07080D","y,	c #000035","z,	c #4D4E4E","A,	c #4E5881","B,	c #6D78AB","C,	c #0F111D","D,	c #474E74","E,	c #3A405F","F,	c #07080C","G,	c #4A537A","H,	c #636DA1","I,	c #6974A8","J,	c #10101A","K,	c #393F5E","L,	c #353333","M,	c #5F6A9D","N,	c #6874A7","O,	c #13121B","P,	c #454D70","Q,	c #3C4263","R,	c #050649","S,	c #1E1E1E","T,	c #222121","U,	c #535C89","V,	c #646DA1","W,	c #6A76AA","X,	c #424B6F","Y,	c #3D4464","Z,	c #4B4A4A","`,	c #333232"," '	c #3B455D",".'	c #1C1B1B","+'	c #272626","@'	c #5D6899","#'	c #6671A7","$'	c #1F2535","%'	c #6A76A9","&'	c #04030A","*'	c #40476D","='	c #444C6F","-'	c #2E3750",";'	c #6C76A9",">'	c #010203",",'	c #24283B","''	c #414469",")'	c #5F6897","!'	c #3E3D3D","~'	c #020100","{'	c #57618E","]'	c #3E456E","^'	c #151820","/'	c #6871A1","('	c #030305","_'	c #5D5E5E",":'	c #383D5D","<'	c #3C406F","['	c #2E344D","}'	c #202174","|'	c #596393","1'	c #121720","2'	c #101B23","3'	c #485078","4'	c #3C4160","5'	c #000022","6'	c #5A638F","7'	c #1C202F","8'	c #5A6390","9'	c #4D557D","0'	c #212437","a'	c #1F2434","b'	c #1C2030","c'	c #1D1F2F","d'	c #222437","e'	c #23273B","f'	c #262A3E","g'	c #494F80","h'	c #535C85","i'	c #494E75","j'	c #23273A","k'	c #1B1F2F","l'	c #1E2031","m'	c #202434","n'	c #2B3148","o'	c #4D5580","p'	c #5E6695","q'	c #626A9C","r'	c #50587F","s'	c #242946","t'	c #171B27","u'	c #171926","v'	c #171A25","w'	c #171A24","x'	c #151826","y'	c #181B23","z'	c #181A26","A'	c #1F2436","B'	c #3D4160","C'	c #58628A","D'	c #1D2030","E'	c #6C76A8","F'	c #646D9F","G'	c #626C9C","H'	c #666FA3","I'	c #6B75AB","J'	c #6974AA","K'	c #1B1E2D","L'	c #6873A6","M'	c #6A74A9","N'	c #1A1D2C","O'	c #5C6491","P'	c #445275","Q'	c #34385C","R'	c #1D2031","S'	c #1C202E","T'	c #1C1E2C","U'	c #1A1D2B","V'	c #1A1C2A","W'	c #181C29","X'	c #191D2A","Y'	c #1C1F2C","Z'	c #1C1F2E","`'	c #1C1F30"," )	c #26293F",".)	c #464C6F","+)	c #575D88","@)	c #646E9F","#)	c #535C84","$)	c #46496E","%)	c #202435","&)	c #1A202D","*)	c #1A1B2B","=)	c #181C2A","-)	c #191B29",";)	c #191C2B",">)	c #191C2C",",)	c #1E2234","')	c #3A3D68","))	c #46547D","!)	c #505A82","~)	c #474F75","{)	c #464B70","])	c #2C3147","^)	c #3D416C","/)	c #282C43","()	c #363A5F","_)	c #3E4270",":)	c #464B6F","<)	c #4C5278","[)	c #545A83","})	c #616B9B","|)	c #3A3F5E","1)	c #010103","2)	c #57618D","3)	c #141521","4)	c #2C2D4E","5)	c #576190","6)	c #1E1F31","7)	c #505A87","8)	c #6A74A4","9)	c #6872A9","0)	c #8B8B8B","a)	c #181B29","b)	c #24273B","c)	c #5A6597","d)	c #272525","e)	c #414040","f)	c #1D2538","g)	c #161926","h)	c #6C76A7","i)	c #0D0C11","j)	c #171616","k)	c #06070A","l)	c #4F5682","m)	c #404669","n)	c #222334","o)	c #636B9B","p)	c #6771A7","q)	c #050508","r)	c #464E73","s)	c #333A54","t)	c #141621","u)	c #6C75A8","v)	c #888888","w)	c #040507","x)	c #6671A4","y)	c #3F4569","z)	c #2F334D","A)	c #696868","B)	c #0F0E0E","C)	c #56608C","D)	c #949494","E)	c #5C6694","F)	c #6571A4","G)	c #3A4160","H)	c #232222","I)	c #2F344B","J)	c #6B75A7","K)	c #12121B","L)	c #3E4464","M)	c #2E3650","N)	c #747272","O)	c #585F8B","P)	c #0F101A","Q)	c #888989","R)	c #050609","S)	c #40476A","T)	c #3A4060","U)	c #06070B","V)	c #5D6692","W)	c #060607","X)	c #6C76AB","Y)	c #626A9B","Z)	c #07070B","`)	c #444D72"," !	c #464C71",".!	c #616B9A","+!	c #6C76AC","@!	c #232532","#!	c #6D6C6C","$!	c #212132","%!	c #535C8A","&!	c #565E8D","*!	c #202031","=!	c #0D0C0E","-!	c #606A9A",";!	c #262B41",">!	c #626B9D",",!	c #111621","'!	c #424A6E",")!	c #989898","!!	c #363F5D","~!	c #161525","{!	c #171B26","]!	c #485178","^!	c #4C547E","/!	c #1F2234","(!	c #191B27","_!	c #373962",":!	c #545D89","<!	c #5C6695","[!	c #212335","}!	c #0A0916","|!	c #5D6696","1!	c #5E6697","2!	c #A0A0A0","3!	c #5A618D","4!	c #606A99","5!	c #5C6493","6!	c #5B628E","7!	c #59618F","8!	c #5F6795","9!	c #535A82","0!	c #4F5980","a!	c #4D527D","b!	c #4F5377","c!	c #444B7A","d!	c #4C5477","e!	c #4D527C","f!	c #50547E","g!	c #515983","h!	c #555D85","i!	c #5B6290","j!	c #A9A9A9","k!	c #5B6593","l!	c #5D6797","m!	c #6A72A3","n!	c #535B89","o!	c #4A507A","p!	c #474C6F","q!	c #282C79","r!	c #272A40","s!	c #222638","t!	c #2A2D44","u!	c #475278","v!	c #4E577F","w!	c #59628F","x!	c #454E77","y!	c #454A70","z!	c #292E42","A!	c #25293F","B!	c #24283D","C!	c #45496E","D!	c #5D6592","E!	c #616A9C","F!	c #4F5885","G!	c #4A547D","H!	c #49537A","I!	c #4F5681","J!	c #535B87","K!	c #5C6490","L!	c #6771A2","M!	c #313853","N!	c #151427","O!	c #1D1F6F","P!	c #5D6897","Q!	c #171A27","R!	c #111023","S!	c #535C86","T!	c #161B24","U!	c #0B0A18","V!	c #151925","W!	c #636D9C","X!	c #0C0B12","Y!	c #383939","Z!	c #555C88","`!	c #4B527C"," ~	c #242323",".~	c #141320","+~	c #4A517D","@~	c #525A85","#~	c #2B2A2A","$~	c #42496C","%~	c #343A56","&~	c #06060A","*~	c #343333","=~	c #505881","-~	c #54618B",";~	c #302F47",">~	c #110F0F",",~	c #56608F","'~	c #0C0B0F",")~	c #545B86","!~	c #4E567D","~~	c #3D4365","{~	c #6974A9","]~	c #797878","^~	c #525981","/~	c #4B547C","(~	c #7C7B7B","_~	c #282727",":~	c #6C6B6B","<~	c #717070","[~	c #4E577E","}~	c #4A5278","|~	c #3B4160","1~	c #606B9D","2~	c #4D547B","3~	c #464D72","4~	c #3D4465","5~	c #403E3E","6~	c #202131","7~	c #585656","8~	c #586291","9~	c #646EA2","0~	c #0B0A0F","a~	c #4A5079","b~	c #454A6C","c~	c #4A5178","d~	c #3C4264","e~	c #0E0E20","f~	c #6A6969","g~	c #5E6899","h~	c #6F6D6D","i~	c #070808","j~	c #1F2435","k~	c #484F75","l~	c #404A6A","m~	c #495078","n~	c #323550","o~	c #797A7A","p~	c #252424","q~	c #706F6F","r~	c #272A3F","s~	c #6873A5","t~	c #414361","u~	c #646C9D","v~	c #0C0C12","w~	c #201F1F","x~	c #030203","y~	c #484F77","z~	c #070606","A~	c #2F324F","B~	c #040407","C~	c #302F2F","D~	c #2E2D2D","E~	c #3C4466","F~	c #282B47","G~	c #373D5B","H~	c #151A23","I~	c #161524","J~	c #131328","K~	c #141A24","L~	c #405073","M~	c #1B202E","N~	c #151D23","O~	c #181927","P~	c #596190","Q~	c #41476A","R~	c #181823","S~	c #3F486E","T~	c #171A28","U~	c #58608C","V~	c #515B87","W~	c #4C5581","X~	c #4A547E","Y~	c #495077","Z~	c #495177","`~	c #4C537A"," {	c #4C567F",".{	c #505781","+{	c #515987","@{	c #5B6591","#{	c #5C6693","${	c #515A86","%{	c #4C567E","&{	c #4A527A","*{	c #485079","={	c #4C537C","-{	c #4D5681",";{	c #5A628D",">{	c #515885",",{	c #4A5277","'{	c #464C6C","){	c #2A2F49","!{	c #25283E","~{	c #23283B","{{	c #262A39","]{	c #252B54","^{	c #444C73","/{	c #3E4069","({	c #161925","_{	c #181B28",":{	c #141622","<{	c #6C74A6","[{	c #6974A6","}{	c #141620","|{	c #4C557D","1{	c #414A70","2{	c #3C4068","3{	c #323659","4{	c #1D2032","5{	c #202334","6{	c #3B3E68","7{	c #3C4B6C","8{	c #464B74","9{	c #535D85","0{	c #5F6999","a{	c #485278","b{	c #40446B","c{	c #3F4263","d{	c #202536","e{	c #1E2231","f{	c #1D1F2E","g{	c #1F2334","h{	c #43486B","i{	c #475178","j{	c #59608D","k{	c #4B547D","l{	c #485279","m{	c #475173","n{	c #44486B","o{	c #454A71","p{	c #485277","q{	c #4B5379","r{	c #575E87","s{	c #151823","t{	c #12131D","u{	c #626DA2","v{	c #2E324C","w{	c #1F1F2A","x{	c #5B6595","y{	c #12161F","z{	c #131924","A{	c #10121B","B{	c #5D6798","C{	c #0C0C11","D{	c #525151","E{	c #12111F","F{	c #676FA0","G{	c #1B2335","H{	c #1F1D1D","I{	c #292727","J{	c #10161E","K{	c #111118","L{	c #3F4968","M{	c #313652","N{	c #504E4E","O{	c #5F699B","P{	c #26283B","Q{	c #505687","R{	c #050509","S{	c #14131F","T{	c #6E77A9","U{	c #0B0A10","V{	c #363C5A","W{	c #545353","X{	c #4B537C","Y{	c #6872A7","Z{	c #575E89","`{	c #30364F"," ]	c #080909",".]	c #4F597F","+]	c #2D314B","@]	c #525353","#]	c #606B9E","$]	c #0E0D0D","%]	c #656EA0","&]	c #4A4F74","*]	c #3D3B3B","=]	c #596293","-]	c #636EA4",";]	c #080C13",">]	c #444F70",",]	c #2F2D49","']	c #818282",")]	c #5E699A","!]	c #6874A8","~]	c #222434","{]	c #424567","]]	c #2D4665","^]	c #4B537B","/]	c #323753","(]	c #050608","_]	c #242B3F",":]	c #393C65","<]	c #3F415E","[]	c #0A0D46","}]	c #0A0808","|]	c #5E679A","1]	c #303854","2]	c #1A1A32","3]	c #484F7B","4]	c #6E76A9","5]	c #151751","6]	c #3F4766","7]	c #485379","8]	c #171625","9]	c #1E2131","0]	c #49527A","a]	c #394767","b]	c #191D28","c]	c #151926","d]	c #353960","e]	c #444E73","f]	c #161B29","g]	c #0A0917","h]	c #181B27","i]	c #666FA0","j]	c #292C41","k]	c #6570A4","l]	c #616C9F","m]	c #5A618F","n]	c #555E87","o]	c #525A83","p]	c #515A82","q]	c #545C86","r]	c #555D8A","s]	c #585F8C","t]	c #515880","u]	c #535A83","v]	c #565C87","w]	c #5A618E","x]	c #636C9D","y]	c #5A628F","z]	c #515883","A]	c #363B56","B]	c #2F344D","C]	c #2C314A","D]	c #292D42","E]	c #272B40","F]	c #2C3149","G]	c #2F334C","H]	c #313651","I]	c #484D71","J]	c #14161F","K]	c #06090D","L]	c #1A1E2D","M]	c #3E416C","N]	c #414D70","O]	c #464E76","P]	c #4F5780","Q]	c #5B628F","R]	c #585E89","S]	c #525D86","T]	c #4E5681","U]	c #49517B","V]	c #465074","W]	c #43476C","X]	c #3A4C6C","Y]	c #21244B","Z]	c #1C2031","`]	c #1A1E2C"," ^	c #191A28",".^	c #191A26","+^	c #131324","@^	c #161625","#^	c #181B2A","$^	c #1B1E2B","%^	c #161C28","&^	c #171925","*^	c #151924","=^	c #ACACAC","-^	c #DADADA",";^	c #DCDCDC",">^	c #BFBFBF",",^	c #B1B1B1","'^	c #B3B3B3",")^	c #C4C4C4","!^	c #D4D4D4","~^	c #E5E5E5","{^	c #F5F5F5","                                                                                                                                                                  ","                                                                                                                                                                  ","                                                                                                                    . + @ @ @ @ @ @ # $                           ","                                                                                                                  % & & & & & & & & & & *                         ","                                                                                                                  = & & & & & & & & & & &                         ","                                                                                                                - & & & & & & & & & & & & ;                       ","                                                                                                                > & & , ' ) ) ) ) ! ~ & & {                       ","                                                                                                                ] & & ^ / ( ( ( ( _ : & & &                       ","                                                                                                                < & & [ ( ( ( ( ( ( } & & &                       ","                                                                                                                & & & | ( ( ( ( ( ( 1 & & &                       ","                                                                                                              2 & & & 3 ( ( ( ( ( ( 4 & & &                       ","                                                                                                              5 & & & 6 ( ( ( ( ( ( 7 & & &                       ","                                                                                                              8 & & & 9 ( ( ( ( ( 0 a & & &                       ","                                                                                                              b & & & c ( ( ( ( ( d e & & &                       ","                                                                                                              f & & & g ( ( ( ( ( ( h i & &                       ","                                                                                                              j & & & k ( ( ( ( ( ( l m & & n                     ","                                                                                                              o & & & p ( ( ( ( ( ( q r & & s                     ","                                                                                                              t & & u v w ( ( ( ( ( x y & & z                     ","                                                                                                              A & & B C ( ( ( ( ( ( D E & & F                     ","                                                                                                              G & & H I ( ( ( ( ( ( J K & & L                     ","                                                                                                              M & & N I ( ( ( ( ( ( O P & & Q                     ","                                                                                                              R & & S T ( ( ( ( ( ( U V & & W                     ","                                                                                                              X & & Y Z ( ( ( ( ( ( `  .& & ..                    ","                                                                                                              +.& & @.#.$.%.&.*.=.-.;.>.& & ,.                    ","                                                                                                          o '.& & & & & & & & & & ).!.~.& & {.                    ","                                                                                                        ].& & & & & & & & & & & & & & & & & & j ^.                ","                                                                                                      /.& & & & & & & & & & & & & & & & & & & & <                 ","                                                                                                    (.& & & _.:.<.[.}.|.1.2.3.4.5.6.7.8.9.& & & & j               ","                                            0.a.b.c.d.e.f.g.F h.i.j.k.l.m.n.o.p.h.; q.r.s.t.u.v.w.x.y.& & & z.A.B.C.D.E.F.:.G.H.I.J.K.L.M.N.O.& & &               ","                    P.Q.R.  ..j S.T.{ U.V.W.] X.# < Y.& & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & Z.`. +.+++@+& & &               ","                  #++ & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & F             ","                j.& & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & $+            ","                & & & & & & %+&+*+=+-+;+>+,+'+)+!+~+{+]+^+/+(+_+:+<+[+}+|+1+2+3+4+5+6+7+8+9+9+0+a+b+c+d+e+f+g+h+i+j+k+l+m+l n+o+p+q+r+s+t+u+v+w+& & &             ","                & & & x+y+z+A+B+C+D+E+F+G+H+I+J+K+L+K+M+N+O+P+Q+R+S+T+U+V+W+X+Y+Z+`+ @.@+@@@#@$@%@&@*@w w ( ( ( ( ( ( ( ( ( ( ( w ( _ =@-@=@;@7 >@& & t.          ","              L & & ,@'@K+)@!@!@!@)@!@~@{@]@^@/@(@@@_@:@<@[@}@|@1@2@2@h+3@3@w w ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( 4@5@& & l.          ","              6@& & ~ 7@!@!@!@)@J+8@9@0@a@2@3@w w ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( b@c@& & d@          ","              e@& & f@g@!@I+!@N+h@i@w Z ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( j@k@& & l@          ","              = & & m@{@!@!@n@o@w ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( _ p@& & q@          ","              & & & r@s@!@t@u@( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( v@& & Y.          ","              & & & w@J+~@x@w ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( y@& & &           ","              & & & z@!@A@2@( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( w B@& & &           ","            C@& & D@E@!@F@w ( ( _ _ _ _ _ =@=@=@=@=@=@=@=@=@=@=@=@=@=@=@=@=@=@=@=@=@=@=@=@_ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ G@/ / ( ( w ( ( ( ( ( p+& & &           ","            R.& & H@I@J@|@K@L@M@N@O@P@Q@R@S@T@U@V@V@V@W@W@X@X@X@X@W@W@W@W@W@W@Y@Z@`@T@ #.#+#@###$#%#Q@&#*#=#>+-#-#O@;#^ N@N@>#,#;#'#w w ( ( ( ( )#& & &           ","            !#& & ~#{#]#Z h ^#& & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & /#( ( ( ( ( (#& & &           ","            _#& & :#I+<#/ [#& & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & }#|#( ( ( ( 1#& & &           ","            2#& & 3#{@4#5#6#& & & 7#< 8#9#0#@ 2#X.X.X.X.X.X.X.X.X.X.X.2#2#2#2#@ @ + + 0#0## '.'.9#9#a#8#a#< b#b#7#7#c#c#c#d#Y.& & & & e#( ( ( ( f#g#& & h#        ","            c#& & i#j#k#=@l#& & X.v.x.m#x.x.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.x.l.l.l.x.x.x.x.x.x.x.x.m#C@x.x.C@C@C@C@C@C@C@C@n#& & & o#( ( ( ( p#q#& & v.        ","            & & & r#s#h+t#u#& & +.w.l.l.l.x.l.l.l.w.w.w.w.w.v.v.v.v.v.v.v.v.v.v#w#v.v.v.v.v.v.v.w.w.w.l.l.l.x.l.l.l.l.l.l.l.l.x#& & & y#( ( ( ( z#A#& & B#        ","            & & & C#D#w I & & & E#v.F#G#H#I#J#K#. L#M#> N#N#!#O#t P#R l@Q#R#S#T#U#S#V#y.l@U.t t N#W#X#Y#K#J#I#Z#`# $.$w.v.v.l.x.9#& & +$=@( ( ( ) @$& & #$        ","            & & & $$%$&$*$& & & T.=$& & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & '.-$;$u.].& & >$3@( ( ( b@,$& & '$        ","          )$& & & }+!$( ~$& & & #+{$& & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & {.V.& & ]$^$w ( ( /$($& & _$        ","          :$& & & <$[$( }$& & & |$& & & & & & & & & 1$2$3$4$5$5$6$7$8$8$9$0$a$b$b$b$c$a$d$e$8$f$g$h$i$& & & & & & & & & & & & X T.& & & j$( ( ( k$l$& & G         ","          n.& & & m$<@_ n$& & Y.o$& & & p$q$r$s$t$u$v$w$x$y$z$A$B$C$B$B$D$E$F$G$H$I$J$K$L$M$N$O$P$Q$R$S$T$U$V$W$X$Y$Z$`$d$& & 9# %& & & .%( ( ( =@+%& & M         ","          t.& & & @%#%/ $%& & a#o$& & & %%&%*%=%=%=%=%=%=%=%=%=%=%=%=%=%=%=%=%=%=%=%=%=%=%-%;%>%,%'%)%!%~%&%{%]%]%]%]%^%/%& & = (%& & & _%( ( ( j@:%& & U.        ","          <%& & [%}%w |#.#& & |%S.& & 1$1%2%=%=%3%3%3%3%3%3%3%3%3%3%3%3%3%3%3%3%3%3%4%5%6%7%8%9%0%a%b%c%d%]%]%]%]%]%]%]%e%& & & f%< & & g%_ ( ( -@h%& & y.        ","          i%& & j%k%2@h+l%& & e@m%& & 5$n%o%=%p%q%r%r%r%r%r%r%r%r%r%r%r%r%r%r%s%t%u%Q#v%2$2$4$4$4$4$2$w%]%]%]%]%]%]%]%d%x%& & & y%z%& & A%B%( ( -@C%& & D%        ","          u%& & E%F%2@2@G%& & H%I%& & J%K%L%=%M%N%N%N%N%N%N%N%N%N%N%N%N%O%N%P%Q%R%S%T%T%T%T%T%T%T%T%T%U%]%]%]%]%]%]%]%]%V%& & & o$_#& & W%h+( ( =@X%& & Y%        ","          o & & Z%`%3@e#& & & O#V#& & e$ &=%=%.&=%=%=%=%=%=%=%=%=%=%+&@&#&$&%&]%]%]%]%]%]%]%]%]%]%]%]%]%&&]%]%]%]%]%]%]%*&& & & '$P#& & =&k ( ( =@-&& & ]         ","          M & & ;&>&3@,&& & & '&)&& & d$!&;%=%=%=%=%=%=%=%=%=%=%=%~&{&]&d%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%^&& & & S.T.& & & /&( ( _ (&& & X.        ","          _&& & :&<&w [&& & & '$}&& & |&1&*%=%=%=%=%=%=%=%2&=%@&3&&&d%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%4&& & & 5&k.& & & 6&( ( _ 7&& & +         ","          $+& & 8&9&w 0&& & &  %a&& & b&c&-%=%=%=%=%=%=%2&=%d&e&d%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%f&= & & g&h&& & & i&( ( _ j&& & a#        ","          ] & & *+k&( l&& & & m&n&& & o&p&=%=%=%=%=%=%=%@&q&r&]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%s&g$& & R t.& & & t&( ( u&v&& & c#        ","          2#& & w&h@( x&& & {$f%+.& & y&z&=%=%=%=%=%=%A&B&d%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%C&D&& & _&r.7#& & E&_ ( ( F&& & =         ","          & & & G&H&_ I&& & J&f +.& & K&L&=%=%=%=%=%M&]%N&]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%b%O&& & P&s.2#& & +#=@( ( Q&& & &         ","          & & & R&S&_ T&& & 9#x.U&& & K&L&=%=%=%=%V&d%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%W&X&& & Y&t.Y%& & Z&j@( ( `&& & &         ","          & & &  *.*=@+*& & @ w#@*& & #*$*=%=%=%%*&*N&]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%**=*& & -*u.P&& & & ;*( ( >*& & &         ","          & & & ,**@K@ #& & '*w#Y%& & #*)*=%2&2&!*]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%~*{*& & ].u.]*& & & ^*( ( /*& & &         ","          & & & (*( 3@A%& & -*w#@*& & #*p&=%=%d&]&]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%~*_*& & :*w#<*& & & *$( ( [*& & &         ","          & & & }*( |@|*& & 1*w#$+& & 2*1&-%%*]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%~*3*& & 4*w#5*& & & 6*( ( 7*& & &         ","          & & & 8*( 9*0*& & -$w#a&& & b&a*;%b*d%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%~*b&& & |%w#c*& & & d*( ( e*& & &         ","          & & & f*( g*h*& & _&w#D%& & =*i*;% &]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%~*b&& & q@w#j*& & & k*( ( 4 & & &         ","          & & & l*( m*n*& & R#w#-$& & c$9%,%o*]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%~*p*& & Y%v.<%{$& & q*/ ( r*& & &         ","          & & & s*( t*u*& & U.v.U#& & d$v*w*d%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%~*x*& & U&v.w.c#& & y*_ ( z*& & &         ","          & & & A*( B*C*& & D*v.E#& & e$E*F*d%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%**=*& & G*v.W a#& & H*/ ( I*& & &         ","          & & & J*( K*& & & m%w.P#& & J%L*M*d%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%b%O&& & -$v.u.X.& & %#K@( N*& & &         ","          & & & O*( *$& & & P*w.Q*& & f$R*d%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%s&f$& & E#v.w#S*& & A%T*( U*& & &         ","          & & & V*( W*& & & X*w.Y*& & g$Z*]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%f&h$& & N#w.v.$+& & `*T*(  =& & & .$      ","          & & & .=( +=& & & @=w.#=& & $=%=]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%]%&=& & & G w.w._#& & *===( (#& & & u.      ","          & & -=;=( >=& & & H#w.,=& & 1$'=]%]%]%]%)=!=!=!=!=!=!=!=!=!=!=!=!=c%d%]%]%]%]%]%]%~=%=%=%=%=%=%=%=%={=]%]%]%]%]=& & & ^=l.l.)&& & & /=( J & & & h.      ","          & & & r*( (=& & & _=l.#+& & & :=]%]%]%<=[=}=}=}=}=}=}=}=}=}=}=}=}=|=]%]%]%]%]%]%]%1=& & & & & & & & 2=]%]%]%]%3=& & & u%l.l.l@& & & k#( 4=& & & b       ","          & & 5=6=( 7=& & & 8=l.$ & & & 9=]%&&]%0=a=b=b=b=b=b=b=b=b=b=b=b=b=c=]%]%]%]%]%]%]%d=e=e=e=e=e=e=e=e=f=]%]%]%&&g=& & & `#l.l.{ & & & h=( O & & & i=      ","          & & j=k=( l=& & & c*l.j.& & & m=w%n=o=p=q=^&r=s=t=u=u=4&4&&=f&f&s&b%)=c%c%c%c%c%{%{%{%c%c%)=)=!=!=^%v=**b%s&]%w=& & & - l.l.Y#& & & g ( x=& & & y=      ","        .$& & z=A=( r*& & & B=l.<%& & & & & & & & = {$h$$=g$O&C=D=E=F=G=H=I=J=K=}=L=M=N=O=P=[=Q=R=S=T=U=V=W=X=Y=Z=`=J%{$& & & c#f l.l. -& & & .-( j+& & & +-      ","          & & @-#-( $-& & & G#l.l.@ & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & H%w.l.l.^=& & & %-( &-& & & *-      ","          & & z==-( #-& & & --l.l.j*0#& & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & Y.h&l.l.l.J#& & & ;-( ` & & & >-      ","          & & & (=( d*& & & h#l.x.l.t..$,-/.'-^=% M U.y.)-!-X z%& & & & & & & & & & & & & & & & & & < ~-c#b#9#{-Y%]--$V#^-@=l.l.l.l.l./-& & & (-( ==& & & n.      ","          & & & (=( _-& & & j*l.l.l.l.l.l.l.l.l.w.w.v.v.v.:-].& & & & & & & & & & & & & & & & & & & <-{ <%w#v.v.v.v.w#v.w.l.x.l.l.l.l.I#& & & [-( }-& & & p.      ","          & & 5=|-( 1-& & & m&l.l.l.l.l.l.l.l.l.l.x.w.5*9#& & & & & & & & & & & & & & & & & & & & & & & = { C@l.l.l.l.l.l.l.l.l.l.l.l.2-& & & ;-( 3-& & & ;       ","          & & 4-|-( V*& & & U#I#<%w.w.x.l.l.l.l.l.C@X & & & & & & & & & {$# q@|%X.# < Y.{$& & & & & & & & & :*5-l.l.l.l.l.l.l.l.v.x.h#S#& & & 6-( 7-& & & r.      ","          & & 4-8-( 9-& & & & & & Y%L#0-W u.v.v.l.+.& & & & & & & Q#5*- v.t.u.t.t.t.W W l.,.#$_$a&& & & & & & Y.5-w.l.l.w.t..$/-U#< & & & & & h+( a-& & & t.      ","          & & 4-6=( b-c-& & & & & & & & & d-e-X & & & & & & = ,=v.v.l.x.l.l.l.l.l.l.l.l.l.l.x.l.u.y%S*& & & & & & X#/-2-O#:*& & & & & & & & f-|#( g-& & & w#      ","          & & 4-6=&$h-A%& & & & & & & & & & & & & & & & & ] <%w.x.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.x.l.e@& & & & & & & & & & & & & & & & & i-j-=@w k-& & & w#      ","          & & l-m-C n-& o-g&W#+ & & & & & & & & & & & & z%..x.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.x.p-& q-r-& & & & & & & & & & & & & & & s-t-I u-& & & v.      ","          & & & ~$v-& = `#w.l.l.% & & & w-x-y-z-A-B-& {$- x.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.i.& & C-D-E-F-G-H-I-J-K-L-& & '.W#. z%& & M-h+N-& & w.      ","          & & & O-P-& Q-l.l.l.x.w.j & & R-S-T-e+j@U-& b#w.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.t.= & V-( W-X-Y-[&Z-#-`-& & Y#v.v.W w. ;& & .;& & & l.      ","          & & +;@;& $+w#x.l.l.x.l.l.m&#;& $;%;( ( &;& < w#l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.w#c#& *$( ( ( d *;=;-;& |%h&v.$ ;;] & ^=>;= & & & & l.      ","          & & & & & @=x.l.l.x.C@,;l.l.,.';& );/&( !;& # v.l.l.l.x.~;{;{;{;{;{;{;{;{;{;{;{;{;r%l.l.l.l.w#b#& ];( ( d k$^;o-& )&/;. 9#& (;_;& :;w.L#& & & & x.      ","          & & & & & (%l.l.x.w.g&7#w.l.l.f%< & <;[;};& # v.l.l.l.r%|;1;1;1;1;1;1;1;1;1;1;1;2;3;l.l.l.l.v.< & 4;( w G@5;6;& l@l.v.W.& 7;v#8;& 5-l.5-& & & & C@      ","          & & & & & `#x.x.v.. & I#l.l.l.l.h&& & 9;0;& a#w#l.l.l.r%a;b;b;b;b;b;b;b;b;b;b;b;c;3;l.l.l.l.w.9#& d;( _ e;& & !#v.x.x.w.V#& Y#2-& w.x.8=& & & & ..      ","          & & & f;& U#v.w.,=& o v.x.l.l.l.l.m&& & g;& b#v.l.l.l.r%h;b;b;b;b;b;b;b;b;b;b;b;a;x.l.l.l.l.v.a#& i;( j;& & O#w.x.l.l.x.t.,=& = @ u.v.!-& & & & i.      ","          & & & k;C*{$5-l.l;& D%..x.l.5-/-l.l.m;& & & c#..l.l.l.n;o;p;p;p;p;p;p;p;p;p;p;p;q;3;l.l.l.l.v.< & r;s;t;& _&l.x.l.l.l.l.x.w.$ # S#v.h#= & & & & i.      ","          & & & _-u;& H%w#w.$ b#] .$v;2#:*v.x.x.]-& & = <%l.l.l.n;w;x;x;x;x;x;x;x;x;x;x;x;y;3;l.l.l.l.w#7#& z;A;& 9#..^=C@l.l.l.l.l.l.l.f >;v.:*& 9;B;& & F#      ","          & & & C;D;c-& 5*l.l.h&+ '.W.b#<%x.l.l.E;& & & ,-l.l.l.r%l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.t.= & 6 F;& #$w#z%:*m&w.x.l.l.l.l.x.w#P#& G;H;I;& & *       ","          & & & J;k$K;& Y.f x.l.i.L;& i%l.l.l.l.i.& & & S#x.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.x.h&& & M;& Y.x.w#:*{$& <*v.l.l.l.l.w.5*& & N;O;P;& & f       ","          & & & J;w m*Q;& ] w.x.l.x.R;w.l.l.l.l.F#& & & # w.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.E#& S;T;& U#l.w#:*U;% & Y&B#l.x.l.V;& & W;Z k$X;& & .$      ","          & & & |-w ( Y;Z;& T#v.l.x.l.l.l.l.l.l.j*& `;& & R;x.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.x.i.7#& f* >& .>l.w#:*#=..+>Y.@>6@w.h#7#& #>$>w %>&>& & (%      ","          & & & 6=( ( ( *>=>& ->v.x.l.l.l.l.x.x.Y&& ;>>>& 7#f l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.v#f d-& ,>I a & & {.w#:*b#c#& & c#].2-a#& '>' ( ( )>!>& & (%      ","          & & & ~>( ( w k${>& & T.u.x.l.l.l.l.V;& ]>^>/>,>& c#X*w.w#w.w.w.l.w.w.w.w.v.w#t.W ,.R;(>& & & _>( :><>& c#[>{ ^-6@$ <%t.(%# & }>|>( ( ( 1>g#& & <%      ","          & & & A*( ( ( w / 2>& & !#t.l.x.l.(%{$& 3>_ ( -.4>& & & a&t #=7;^=_$5&. > R 5>6>& & & & & 7>8>( w w 9>0>& & X#v.w.l.u.l;& & a>|>( ( ( ( 1>b>& & ,.      ","          & & & c>( ( ( ( w d>e>& & U&>;<%f>#;& g>h>( d ( &-i>j>& & & & & & & & & & & & & & k>v+l>m>n>( w ( ( &$k o>= & b#Y*_$.>& & p>q>( w ( ( ( 1>r>& & f%      ","          & & & i&( ( ( ( ( w s>t>u>& & Y.& & v>w>&$( ( ( ( _ &-#-x>y>t+z>A>B>C>D> #;#E>F>l [;;@=@( ( ( ( ( ( ( w G>H>I>& & & & f;J>K>( ( ( ( ( ( t#D@& & B#      ","          & & & L>( Z ( k$n>M>l =-N>O>& & & P>Q>C;R>S>T>=@w w ( _ U>V>W>7=X>Y>Z>`> ,.,+,@,#,W>' $,( w ( w _ %,%,&,==V>*,N>=,-,;,>,}-,,W-%,_ w ( ( t#',& & h&      ","          & & & 8*( |#),!,& & & & & & & & & & & & & & ~,{,_ ( f#],@$& & & & & & & & & & & & & & ^,0;( ( /,(,_,:,& & & & & & & & & & & <,[,},Z w ( t#r>& & B#      ","          & & & |,( 1,2,& & {$# 2#6>].+.$+Y%3,z%@ a#& & 4,5,( 6,& & & < + + @ X.|%:*X.7,X.(;~-& & 8,T ( 9,& & & & & & & {$c#0,& & & & & & & r;( ( /=a,& & f%      ","          & & & (*( m+& b,c,* ..x.l.v.u.0-w#w.l.x.i..$9#& d,( e,& :*,.F#h#c#{$Y.c#b#7#F#x.C@F#5-& & f,=@g,& ^-_=h,B#j*;$c*c*i,;$8=Z#j j,_#& k,/ ( 1>g#& & <%      ","          & & & l,*@m,& X.t.l.l.l.w.u%Y%X.v.l.l.l.l.l.g&& n,( o,& m%l.l.S#] |$|$5*Y.Y.f%l.l.l.v.c#& p,j@q,& f%l.l.l.T.& & & & & & y.r,l.d@& s,t,( %>&>& & (%      ","          & & & u,_ v,& '*w,l.l.C@2#& 8#|%v.l.l.l.l.l.6@& x,_ y,& z,l.x.v...l...# b#,.l.x.l.l.w.b#& A,B,& & .$l.l.l.f 5-B#@=c#b#|$v.x.l.m&& & ==( %>C,& & f       ","          & & & D,_ E,& $+v.l.l.l.I#- ->|%v.l.l.l.l.l.u%& F,/ & & 8=l.l.l.l.i.9## i.l.x.l.l.l.l.'.& G,H,& & F#x.l.l.l.l./-& & +.m%E;l.l.* & & e#( I,J,& & F#      ","          & & & j&=@K,& e@v.l.l.x.w.w.L,|%v.l.l.l.l.l.u%& F,( & & j l.l.l.F#X.2#x.u.u.l.x.l.l.l.a#& }*M,& & i.l.l.l.l.l.l.(%'-_;& T.w.l.* & & e#( N,O,& & i.      ","          & & & P,_ Q,& .>w#l.l.l.l.w.L,|%v.l.l.l.l.l.7;& R,( & & R;l.l.i.|%& S,T,e@@*h&l.l.l.w.7#& U,V,& & F#l.l.l.l.l.l.l.l.s.+ 5&w.l.h,& & G>( W,>@& & ..      ","          & & & X,_ Y,& Y%w#l.l.l.l.w.Z,`,w.l.l.l.l.l._;&  '( & & I#l.x.R#.'}&+'V#U.D*,.l.l.l.v.Y.& @'#'& & r,l.l.x.v.v.v.v.v.W # 5&w.l.=$& $'G>( %'&'& & x.      ","          & & & *'_ a & + q.v.w.w.w.l.v.w#l.w.w.w.w.t.2#& ='( -'& M w#w.t.t.u.w#v.v.v.w.w.w.v.W = & s;;'>'& (%l.l.u.D%_#H%V#R a#& R.w.w.T.& ,'|#( u-& & & w.      ","          '.& & ''_ )'& & ]-Q#> m%. o J#X*_$. !'> l@$+& ~'{'( ]'& {$W.t g&L#T.,=S.2-A % W#N#_&@ & ^'/'j@('& P#,=#+j d-].|%@ c#P&'$_'5*'&z%& :'5#( u-& & & v.      ","          :*& & <'_ 9*['& & & & & & & & & & & & & & & & }'G>( |'1'& & & & & & & & & & & & & & & 2'3'Z ( 4'& & & & & & & = {$= & & & & & & 5'6'( ( a-& & & u.      ","          |%& & 7'_ ( g*8'9'Q@T@,'0'a'b'c'A-d'e'f'=#g'7 1@w ( w g h'i'R@Y@j'z>A-k'l'm'D>X@+#n'o'p'( w &$q'r's'c''>t'u'v'w'x'y'u'u'z'x-A'B'C'/ ( ( k-& & & t.      ","          @*& & D'=@( w ( ( _ =@=@-@j@j@j@j@-@=@=@_ ( ( ( ( ( ( ( ( ( _ =@B%j@j@j@j@j@-@=@_ ( ( 0 ( ( ( d ( =@j@E'k$==z#F'G'p#H'T*t#E'j@_ ( w ( ( I'& & & s.      ","          S,& & =,B%( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( J'& & & s.      ","          H%& & K'B%( ( w ( =@j@=@L't,i@&-1@==n>k$j@-@_ w ( ( ( ( ( _ j@j@/=n>;@&-&-;@==L't#j@=@( w ( ( ( ( ( w ( _ _ =@B%-@-@=@=@_ _ ( w ( ( ( ( M'& & & r.      ","          S#& & N'=@&$h+O'P'Q'R'S'T'U'V'W'X'U'Y'Z'`' ).)+)( ( Z @)#)$)%)D'Z'&)*)=)-);)>)T'=,,)')))S-( ( ( ) (=!)~){)])^)/)u+t+()_)4':)<)[)})Z w ( M'& & & q.      ","          R & & ;)=@_ |)& & & & & & & & & & & & & & & & 1)2)( /'3)& & & & & & & & & & & & & & & & 4)/'w 5)6)& & & & & & & & & & & & & & & & 7)8)( 9)& & & 0)      ","          M & & a)B%h+b)& U&{ ^=I#l;k.j,V;P#k.#+'-J#m%|%& m'( c)& & y.G X*'-|$j {.0-`#o$l;I#o { o-& 5)( t>& & ] d)Q#t > L#Y#e)W#->t Q#D%'.& f)G>( 1>& & & h.      ","          % & & g)h)h=i)&  $w.l.l.l.l.F#j)!#l.l.l.l.w.o$& k)=@l)& c#w#w.l.x.S#e@Y%z%#;@*x.l.w.v.3,& m)_ n)& '&w#v.v.x.8=k.k.k.k.x.v.v.v.(%& & o)( p)& & & Q       ","          2-& & 7>j@6-& & w.l.l.l.l.f ].& !#l.l.l.l.l.j.& q)-@r)& b#l.l.x.x.0,D%> ^-. S.x.l.l.l.U.& s)=@x,& #$l.l.l..$o-& = = {$(%l.l.l.x.a#& o#0 b@& & & o.      ","          5*& & t)u);-& & v)l.l.l.<%2#a#+ t l.l.l.l.l.f%& w)x)y)& 2#x.l.l...& a&Q*G ,='$o$x.l.l.m%& z)=@F,& j.l.l.l.f {$Y#8=B=A),.i.l.l.w.B)& C)( ) & & & D)      ","          o$& & ,>u)E)& @>s.l.l.m&b#2#E;3,R w.l.l.l.l.,.& w)F)G)& .'l.l.x.x.W#H)@*@ {$& & C@x.l.X#& I)J)k)& m&l.l.l.f c#& & & & & ].w.l.v.z%& };( i@& & & i=      ","          j*& & K)u)p'& b,v)l.k.& & & & & @ v.l.l.l.l.- & w)k$L)& ].l.l.l.l.w.w#u.t.s.#$& i.l.l.->& M)j@k)& E;l.l.l.f = #$..(%N)-$+.w.l.w.2#& O)( V,& & & n       ","          ,.& & P);'/&& & Q)C@V;V;V;V;#$].'.u.l.l.l.l.$ & R)B%S)& @ x.l.l.l.x.f>#+'-n#N#& F#l.l.-$& T)-@U)& [>l.l.l.f Y.J&a#a#a#0,+.w.l.x.< & V)w f#& & & y=      ","          x.& & W)X)Y)& & w.l.l.l.l.l.w.)-9#u.l.l.l.l.|$& Z)_ `)& b#l.l.l.l.x.D%& {$c#< Y%C@l.l.:*&  !=@F,& y%l.l.l.i.<*P*P*P*P*P*I#l.l.i.& & .!( G'& & & i=      ","          v)& & & +!h=@!& ^=#!* l.v.v.v.m&2-v.v.x.(%--d)& $!( %!& Y.V;B#..w.v.F#F#x.v.W W i.5-j {$& &!_ *!& _$v#v.v.v.v#w#w#w#w#w#v.v.v.:;& =!V>( -!& & & D)      ","          m.& & & 3-K@;!& & & & & & & c#< c#& & & & & & & x&( >!& & & & & & & = 7#7#= & & & & & & ,!@)( '!& & & @ 3,U&]-W.)&P&Y&+.].z%{$& & f'K@( /&& & & v)      ","          )!& & & x)( q !!U'~!& & & & & & & & & & & {!%)]!K@w w ^!/!l$& & & & & & & & & & & k>(!_!:!( w <![!& & & & & & & & & & & & & & }!v+|!( ( 1!& & & x.      ","          2!& & & U ( ( =@) K>F'6-)'x 8'3!I*U*/&S>p#9>g+_ w ( w ( %,` i@k 4!M>5!6!7!5!8!4!t*m*;@=@( w ( ( T*@)m+'#9!0!a!b!c!d!e!f!g!h!i!g |#( ( ( p'& & &         ","          j!& & & 4=( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( w ( ( ( ( ( ( ( ( ( ( ( ( ( ( k!& & &         ","          z & & & l!( ( ( ( ( _ _ _ =@-@-@=@=@_ _ _ ( ( ( ( ( ( w ( ( _ _ _ =@=@-@-@=@=@_ _ ( ( ( ( ( ( ( ( ( w ( ( ( ( ( ( ( ( ( ( ( 0 ( ( ( ( ( (=& & &         ","          h.& & & q m!=@j$n!o!p!q!r!U@s!u+e'Z@%#t!u!v!w!@)w w ( %,l }$x!y!z!A!,'0't+B! #&#C!B-}$D!( w w ( j@E!Y-m-r;F!q+G!H!|,I!}$J!!;K!l+J)m!( ( z*& & &         ","            & & & A=L!M!N!& & & & & & & & & & & & & & & O!:>( P!Q!R!& & & & & & & & & & & & & & 2'D,( ( S!R'T!& & & & & & & & & & & & U!V!z'$>w ( =.& & &         ","            & & & 7*W!X!& '.a&V#P#Y!L#T.5&G { !#R _&Y%& ~'Z!( `!& & X. ~U.D*g&X#Y#% ^-M t Q#}&@ & .~I _ a'& & c#a#+ |%@*a&}&e@@*3,2#9#c#& & +~( ( =-& & &         ","            & & & @~7!& c#q.w#v.- (>#~#~#~T#i%w.w.v.t.j)& $~( %~& S,t.w.S#U.N#W#U;_$X*h&w.v.w#W = & -!j@&~& /.f B=5*'$'$'-'-'-'$h&t.u.F#*~& A%f+( 8>& & &         ","            & & & =~-~& :*u.l.l.[>W.P&P&D%& j,l.l.l.l.P*& R)( ;~& T.l.C@& >~+.] @ < & '$l.l.l.w.c#& ,~T-w)& ,.w.S,& = = = = = & /-l.l.l.c*& '~T*( )~& & &         ","            & & & !~~~& Y%w#l.l.l.v.v.v..$& h#l.l.l.l.d@& F,5#& & 6@l.x.= M#v.v.v.v.& 5*l.l.l.l.< & `&{~& & ]~v.@*U.w#v.v.v.s.'.R.l.l.l.f%& & V>( ^~& & &         ","            & & & /~|)& d-v.l.l.l.l.l.l.B#& 5-l.l.l.l.u%& F,( & & j,l.l.Y.a&,- $h&f%& 5*l.l.l.l.# & q*;.& & (~v.] _~{.:~<~x#* 9#R.l.l.l.* & & e#( [~& & &         ","            & & & }~|~& $+v.l.l.l.l.l.l.5-& * l.l.l.l.'$& F,( & & o$l.l.9#& & & & & & R.l.l.l.l.< & ^!1~& & i.w.H%& & & & & & & R.l.l.l..$& & e#( 2~& & &         ","            7#& & 3~4~& L;w#l.l.l.l.l.l.m&& v.l.l.l.l.5~& 6~( & & 7~l.l.:*6>- y%i%j 7#<*l.l.l.w.c#& 8~9~& & F#x.l.,.- #!A)G#`#< R.l.l.l.{.& 0~==( a~& & &         ","            # & & b~c~& q@u.l.l.l.l.l.l.#!& v)l.l.l.l._&& d~( e~& J#l.l.|%z%f~f~f~f~+ M x.l.l.v.{$& g~3-& & f l.l.l.<%f~f~f~h~i~S.l.l.l.m;& j~G>( k~& & Y.        ","            :*& & l~z*& < i.x.t.u.u.w#w#f T.v)u.t.w.(%c#& m~( n~& _&o~v.|%& & & & & & p~u.t...q~& & k+j@q)& .$w#v.w.T.& & & & & q~w.v.u.M#& r~s~_ r)& & <         ","            $+& & t~u~v~& d#'.X.3,+.Y&H)H%w~+.].{-# Y.& x~w>( y~& & z~+ c#< # :*].] 2#+ |%2#8#& & A~T =@B~& 2#}&R D*O#C~!#> `,D~M O#y.$+Y.& E~_ _ 7&& & #         ","            S#& & F~%,G~H~I~& & & & & & & & & & & & J~K~L~/ ( 4@M~N~& & & & & & & & & & & & & F-O~P~( ( Q~R~& & & & & & & & & & & & & & & A#h>( _ S~& & X.        ","            N#& & T~B%=@h+)#U~V~k*W~X~Y~Z~`~ {.{+{8>@{9>=@w w ( j@6-#{~>${I!%{&{Q>*{={-{F!J!;{8!J)( w w -@-.>{,{'{){!{~{u+W%s!V@{{]{^{|,_-h+( ( B%/{& & $+        ","            A & & ({:>( ( d ( ( ( ( ( _ _ ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( G@_ _ ( ( ( ( ( w ( ( ( ( ( w ( _ _ _ _ _ =@=@=@_ _ _ _ ( ( w ( ( -@_{& & P#        ","            5*& & :{T*( w ( _ =@-@j@=@K@s~/=<{j@-@=@_ 0 ( ( ( ( ( ( ( =@B%j@=@/ T*[{k$j@j@B%_ ( 0 ( ( ( ( ( ( d ( ( ( _ _ _ _ _ ( ( ( w ( ( ( ( K@Q!& & A         ","            $ & & }{==|#6*|{1{2{3{/!A>D'c'4{A-5{6{7{8{9{0{&$w ( V>~>a{b{c{d{/!e{f{D'_,g{C>c{h{i{j{Z m!w _ T*/,e*L>k{l{m{`)n{o{v&p{q{o'r{M>==( ( ) s{& & /.        ","            ,.& & t{u{v{& & & & & & & & & & & & & & & & w{T*( x{y{& & & & & & & & & & & & & & & & S)s>( `&-)& & & & & & & & & & & & & & & z{@)w z#y{& & ,.        ","            t.& & A{B{C{& $+Q#W#% A J#D{:-S.,=P*e)M X & {$l*( F&& & w~D*m%d#= < 2#] @*U&*~L#P#e@& E{F{_ G{& & + +.H{P&_~Q#P#Q#I{ ~w~+.X.& & 4~G@x=J{& & F#        ","            h#& & K{U,& b#r.v.w.w.l.l.l.l.l.l.w.w.w.u.a&& L{( M{& !-w#v.l.7#q@U&] {-+ & N{w.v.t.{$& O{j@>@& j.x.v.v#t.t.v.v.v.v#w#w#v.l.m%& P{K@x=& & &           ","              & & & Q{& 6>u.l.x..$v.x.x.w.--v.x.l.l.l.A & R{5#S{& 7;l.l.C@@>R;u.u.w.l.= N{l.l.w.7#& U,T{>'& <%l.x.v.X#D~v.l.0-2-C@l.l.l. %& U{T*+=& & &           ","              & & & V{& j)w#l.[>& W#w.w.Y#& 7~l.l.l.l.d@& F,/ & & W{l.x.C@& |$l.l.l.l.= N{l.l.l.a#& X{Y{& & f l.w.V#9#7#o u%{ c#C@l.l.l.,.& & V>Z{& & &           ","              & & & `{& e@v.l...-*& b#a&& z%i%x.l.l.l.#+& F,( & & j l.l.i.& j,l.l.l.l.= N{l.l.l.# & G,M,& & i.x.w.m%# =  ]& & & & c,l.l.* & & e#.]& & &           ","              & & & +]& $+v.l.x.)&a#& & & @>'-l.l.l.l.@]& x,( & & >;l.l..$& $ l.l.l.l.= N{l.l.w.b#& 8*#]& & i.l.x.w#_&$]v)u.T.Y.R.i.l.l.(%& & %]&]& & &           ","              & & & >+& L;w#l.x.X*& w~0-w~& V.(%l.l.l.*]& n,( & & @=l.l.,.& i%.$<%B#h&= N{l.l.w.c#& =]-]& & F#x.j.7#{${$S,_~d-{$. w.l.l.$ & ;]f+>]& & &           ","              & & & ,]& ] u.l.l.g&^-v.x.']R;|%B=l.l.w.H%& 4~( z=& Z,l.l.h&& Y.= & & & & Q-l.l.w#{$& )]!]& & ]~l.<%^=] Y.U.)&{-& q@w#l.x.6@& ~]/={]& & @           ","              & & & ]]& J&(%v.s.v)s.t.t.u.t.v)s.s.u.5-= & ^]( /]& W.(%s.x.6@#+8=#$0-[>c,w.s.C@#$& & h=j@(]& f t.w#w#U#R.u.u.{.'&t.w#u.W > & _]U>:]& & a&          ","              7#& & <][]& & & & Y.a#@ |%] 2#}]c#& & & & `-|]( `&& & & & & b## X.'*6>+ < {$& & & & 1]3@=@2]& & z%1*p~_;U.O#M t Q#)-H)d-9#& & 3]4]5]& & %           ","              q@& & 6]7]V'8]& & & & & & & & & & & & J~9]0]u&( h>a]b]k>& & & & & & & & & & & & c]d])'( ( e]f]& & & & & & & & & & & & & & g]h]i]T*t)& & =$          ","              R & & j]1>k]l]g 6*m]=-n]o]p]q]r]l=(=(-6-) _ ( w ( =@%]6-#{6's]@,S!t]u]v]|-w])#})x]B%( ( w _ x=y]z]A]B]C]O@D]E]>+F]G]H]I]V*w>k]k#|>J]& & (%          ","              X*& & K]^,L]_,%)M]N]O]}*P]@~@,e #{/,x]9>2@L'M'a-%,t#t#%,%,%,%,$,k$k$%,k$%,%,)>t#t#k$k$a-M'/$1@U s;/,[-Q]R]S]T]U]V]W]X]Y]A-Z]`] ^.^& & & +-          ","              E;& & & & & & & & & & & & & & & & & & & & & & & +^@^($ ^a)#^+%;)U'$^8&U'+%a)%^&^({*^z{& & & & & & & & & & & & & & & & & & & & & & & & &             ","              =^& & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & :*            ","                2!  <%y%u%Y#U.W.z%a#Y.& & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & b#+ :*P&Q#^-2-=$y%..2#R -^            ","                                P.;^^.>^,^:$t.[>5-Q n.0)u...,.[>i%o$/.|$R;u%d@'$6@R.'$u%|$o$V;i%h#[><%..W p.n.v.- h#w#F '^)^!^~^{^                                ","                                                                                                                                                                  "],
    'PHONE': ["12 18 42 1"," 	c None",".	c #000000","+	c #FFFFFF","@	c #343234","#	c #4C4A4C","$	c #5C5A5C","%	c #9C9A9C","&	c #FCFAFC","*	c #ECEAEC","=	c #C4C2C4","-	c #BCBABC",";	c #ACAAAC",">	c #8C8E94",",	c #CCCED4","'	c #4C5254",")	c #545654","!	c #A4A6A4","~	c #848684","{	c #FCFEFC","]	c #F4F6F4","^	c #ECEEEC","/	c #E4E6E4","(	c #D4D6D4","_	c #CCCECC",":	c #FCFAB4","<	c #FCF28C","[	c #FCF29C","}	c #746604","|	c #746E44","1	c #7C6A04","2	c #645604","3	c #C4AA0C","4	c #84720C","5	c #FCEA84","6	c #6C5A04","7	c #E4C23C","8	c #FCDE5C","9	c #FCE26C","0	c #FCEEBC","a	c #ECD27C","b	c #D4AE3C","c	c #C4B68C","         @  ","         @( "," !!!!!!!!$( ","!*^^^^^***~ ","!^{26626-!$*","!^6c:::b|!),","!*60:[<72!$_","!^2a59836!)_","!*6641}66!$_","!*{{{{{&{!),","!*/-&;,%,!$_","!^=)!)!$!!)_","!*{!&!*%*!$_","!^;$!'>#>!),","!*&!/!,!,!)_","!!!!!!!!!!$_"," $$)$)$)$);_","  _________]"],
    'CALENDAR': ["16 16 60 1"," 	c None",".	c #3C3A3A","+	c #868585","@	c #1581BF","#	c #86B1CA","$	c #157CB6","%	c #1F84C0","&	c #AFD5F2","*	c #A3C2D7","=	c #8CC3ED","-	c #5DACE1",";	c #6AB2E2",">	c #59A8EC",",	c #288FD2","'	c #007ABC",")	c #9BBDD1","!	c #FDFDFD","~	c #8BA7BA","{	c #B6B6B6","]	c #E6E5E5","^	c #A8A7A7","/	c #0D0D0D","(	c #383838","_	c #C7C7C7",":	c #D8D7D7","<	c #D2D2D2","[	c #B5B4B4","}	c #646363","|	c #E8E7E7","1	c #D9D8D8","2	c #CBCACA","3	c #828181","4	c #CFCECE","5	c #D4D3D3","6	c #EBEAEA","7	c #DCDBDB","8	c #B0AFAF","9	c #EFEEEE","0	c #2B2B2B","a	c #959494","b	c #C5C5C5","c	c #F2F2F2","d	c #848484","e	c #F6F6F6","f	c #BDBDBD","g	c #FEFEFE","h	c #FAFAFA","i	c #E5E5E5","j	c #CFCFCF","k	c #EFEFEF","l	c #D9D9D9","m	c #F5F5F5","n	c #D5D5D4","o	c #AFAFAF","p	c #AEAEAE","q	c #ADADAD","r	c #ACACAD","s	c #B0B1B1","t	c #B0B0B0","u	c #DADADA","   .+     .+    "," @@@.#@@@@@.#@$ "," %&&.*&&=-;.*-% "," %&&&&&=>>>>>>% "," ,''''''''''''% "," )!!!!!!!!!!!!~ "," {]]^/(_]:/<]]{ "," {]]/]/[]}/<]]{ "," {|||1/234/5||{ "," {667/86////66{ "," {990//a99/b99{ "," {cccccccccbccd "," {eeedfdfddge[[ "," {hhhijjijikl[{ "," {mmmmmmmmm[[]{ "," noppqqqqrdpstu "],
    'TODO': ["16 16 77 1"," 	c None",".	c #FFFFFF","+	c #FBFDFE","@	c #D0D8E0","#	c #8091A7","$	c #0034A1","%	c #935F00","&	c #FBFCFE","*	c #C6CFD8","=	c #3194E2","-	c #A5D7F4",";	c #009DFF",">	c #B67A00",",	c #434F5F","'	c #27333E",")	c #995B00","!	c #CE9100","~	c #D1FAFF","{	c #F6FAFC","]	c #28333F","^	c #F62400","/	c #B0BCCA","(	c #BDC6D0","_	c #F3F6FB",":	c #E9EFF5","<	c #0C6CCD","[	c #8895A0","}	c #FFFAE7","|	c #FFCB52","1	c #C81500","2	c #8193A9","3	c #B3BEC8","4	c #5D6671","5	c #5D3A00","6	c #5F6772","7	c #69737F","8	c #0869CC","9	c #AFBAC6","0	c #ECEFF2","a	c #CDD6DF","b	c #E4E8EC","c	c #7E8A96","d	c #727E89","e	c #FAFBFE","f	c #818D99","g	c #E0E4E8","h	c #A6ABB0","i	c #C3CCD6","j	c #7F8C98","k	c #BEC1C6","l	c #CF3A15","m	c #7A8893","n	c #B9C3CE","o	c #F9FAFD","p	c #FFCCFF","q	c #E6EDF4","r	c #FBFDFD","s	c #66707C","t	c #C51300","u	c #036BD5","v	c #FCFDFE","w	c #606974","x	c #FFF9D0","y	c #4A535F","z	c #B8C4D1","A	c #E7EAEE","B	c #CD320B","C	c #636D77","D	c #49535E","E	c #FDFEFE","F	c #F0F4F9","G	c #788490","H	c #6F7A85","I	c #0669D0","J	c #6D7782","K	c #F4F8FA","L	c #75818D","  !  !  !  !    ","[2>##>##>##>2[  ","j.)..)..)..).f  ","m.,/.,/.,/.,zc  ","G...............","L.r++++++++E.Bt.","d.a@@@@@@@0.<^pl","H.o&&&&&ev.<-.^1","J.i*****A.8-~=^1","7.K{{{{+.I-~=;$.","s.n(((b.u-~=;$..","C.F___.%-~=;$.. ","w.933g.%|=;$.k  ","4.q::.%}x|$..4  ","6.....%}55...6  ","D]'''.]%..h']y  "],
    'FOLDER': ["16 16 77 1"," 	c None",".	c #FFFFFF","+	c #FFCC00","@	c #5D3A00","#	c #986500","$	c #936000","%	c #FFFF00","&	c #FFE500","*	c #FFD400","=	c #956200","-	c #FFC900",";	c #D4A100",">	c #946100",",	c #FFCE00","'	c #946000",")	c #ECB900","!	c #C69200","~	c #FFE700","{	c #CC9900","]	c #FFC800","^	c #FFCD00","/	c #E6B300","(	c #FFD100","_	c #C99500",":	c #B68000","<	c #7E5300","[	c #935F00","}	c #CD9A00","|	c #FFDD4F","1	c #FFD73A","2	c #FFCA00","3	c #E3CE90","4	c #C79100","5	c #FFE784","6	c #E4B100","7	c #EBB800","8	c #FDCA00","9	c #EAD392","0	c #FFE7AE","a	c #FFFFD5","b	c #CE9B00","c	c #A77200","d	c #FFD300","e	c #FFDB3D","f	c #D5AC32","g	c #BE8B03","h	c #B88200","i	c #BA8600","j	c #B88400","k	c #935E00","l	c #C08C00","m	c #FFE072","n	c #FFDE61","o	c #D19D00","p	c #FFD310","q	c #FFE682","r	c #FFF6CB","s	c #FFE083","t	c #FDC900","u	c #FFE295","v	c #AF7B00","w	c #FFDA2A","x	c #C58F00","y	c #915B00","z	c #966000","A	c #B78100","B	c #C89500","C	c #F0BD00","D	c #FFEB3A","E	c #E9B600","F	c #795000","G	c #FFF8CC","H	c #FFFFCF","I	c #FFE33E","J	c #935D00","K	c #FFCB00","L	c #D8B134","                ","                "," ''>>>          ",">0t8++$====#    ","$u6//E7)))C=    ","$so;;;;b!x4yJk'#","$m_{{}BlL......#","$n!ihA:f.q]--,# ","$|jg....5-++,,# ","$ec9r]--2+++(#  ","$wv.1K+++++^^#  ","$p3G(d******#   ","[I.D&&&&&&~~#   ","zaH%%%%%%%%#    ","<@@@@@@@@@@F    ","                "],
    'FILE': ["16 16 120 2","  	c None",". 	c #FFFFFF","+ 	c #DCFFFF","@ 	c #DF78FF","# 	c #0062C9","$ 	c #C8C8FF","% 	c #EDF2F4","& 	c #F5F2F3","* 	c #FBFBFB","= 	c #C8C7FF","- 	c #F5F8F7","; 	c #0090FB","> 	c #00228E",", 	c #005FCA","' 	c #0060C9",") 	c #0064CA","! 	c #3EB4FF","~ 	c #0062CA","{ 	c #31AFFF","] 	c #002A93","^ 	c #D6D9FA","/ 	c #008EF9","( 	c #0065CC","_ 	c #EBF1F3",": 	c #C6C6FF","< 	c #AAD6FF","[ 	c #002994","} 	c #005FC7","| 	c #B7EDFF","1 	c #0064CB","2 	c #C5C5FF","3 	c #0065CB","4 	c #002F96","5 	c #0066CD","6 	c #12A1FF","7 	c #F4F7F7","8 	c #F3FFFF","9 	c #E979FF","0 	c #0063C9","a 	c #FAFBFA","b 	c #F4F1F2","c 	c #029DFF","d 	c #0145AA","e 	c #004CB2","f 	c #0060C8","g 	c #002C94","h 	c #D6D0FF","i 	c #B0DEFF","j 	c #0B7CDE","k 	c #0075DE","l 	c #E0DEFC","m 	c #0075E4","n 	c #0063CA","o 	c #FEF6FF","p 	c #0067CF","q 	c #0065CF","r 	c #007BE7","s 	c #24AAFF","t 	c #3CB3FF","u 	c #6DCCFF","v 	c #E7E6F9","w 	c #006AD3","x 	c #0081E9","y 	c #E4E3FF","z 	c #002A94","A 	c #1D75D4","B 	c #0092FA","C 	c #46B9FF","D 	c #0061C9","E 	c #1F81DA","F 	c #DBDFF7","G 	c #0068CE","H 	c #EEF0FA","I 	c #0066CC","J 	c #00218C","K 	c #AAD7FF","L 	c #002E94","M 	c #002E95","N 	c #0066D1","O 	c #0067D3","P 	c #0089F1","Q 	c #0062CD","R 	c #E7E9FC","S 	c #008AF6","T 	c #001F8B","U 	c #001A8B","V 	c #0446A9","W 	c #3FB6FF","X 	c #CECFFD","Y 	c #008DF9","Z 	c #F1E9FF","` 	c #33AFFF"," .	c #14A6FF","..	c #E7E0FF","+.	c #0089F0","@.	c #00218D","#.	c #EEEEF7","$.	c #0064CC","%.	c #FEFEF8","&.	c #002B94","*.	c #00258F","=.	c #001888","-.	c #0072DB",";.	c #ACD7FF",">.	c #D1D2FD",",.	c #0094FF","'.	c #0052BD",").	c #0149AD","!.	c #E2DDFF","~.	c #12A0FF","{.	c #0074E0","].	c #E0DAFF","^.	c #007AE3","/.	c #DBD6FF","(.	c #81B9F4","_.	c #33B4FF",":.	c #006DD8","<.	c #001988","[.	c #079CFF","}.	c #12A2FF","( } 9 @ @ @ @ @ @ @ @ @ @ 9 } ( ","~ | 8 + + + + + + + + + + 8 | ~ ","5 <.. a * * * * * * * * a . =.5 ","n _.. 2 = = = = = = = = 2 . u ~ ","# { . 7 - - - - - - - - 7 . C D ","# { . : $ $ $ $ $ $ $ $ : . s # ","# { . _ % % % % % % % % _ . c 0 ","# ` . b & & & & & & & & b . ,.0 ","# t [.S / ; ; ; ; ; ; / Y A B ) ","# ! ~.+.'.J > > > > @.1 f (.P ) ","# ! 6 r . . . . . . . , ' ;.x ) ","# ! 6 {.. U m !.$ X l , ' < ^.3 ","1 W }.:.. *.k h >.^ v , ' < -.3 ","d E  .N o T O /.^ F #., ' K w I ","  V j q Z ]...y R H %.Q $.i p G ","    ).M &.] ] ] [ [ z 4 4 g L e "],
    'CONTACT': ["16 16 110 2","  	c None",". 	c #F3C695","+ 	c #E68A4F","@ 	c #E99662","# 	c #E99661","$ 	c #E99561","% 	c #E99560","& 	c #E8935D","* 	c #F4D4AD","= 	c #E78B51","- 	c #FFF8C5","; 	c #FFF9D4","> 	c #FFF7CE",", 	c #FFF7CD","' 	c #FFF5CB",") 	c #FFF3C9","! 	c #FFF1C4","~ 	c #F4BC7D","{ 	c #EDC9A6","] 	c #E78A50","^ 	c #FFF7C2","/ 	c #FFF2AB","( 	c #FFF0A4","_ 	c #FFEEA1",": 	c #FFEB9D","< 	c #FFE89A","[ 	c #FFE497","} 	c #FFE8AB","| 	c #F3B776","1 	c #E78E55","2 	c #E78E56","3 	c #E8915A","4 	c #FFF5BE","5 	c #FFF0A5","6 	c #FFF3CE","7 	c #C09F7D","8 	c #C2A794","9 	c #F8E8B8","0 	c #FFDB83","a 	c #FFDE97","b 	c #FFE1A7","c 	c #FFDCA4","d 	c #FFD873","e 	c #E88F57","f 	c #EAEAEA","g 	c #FFF5BD","h 	c #FEF0C5","i 	c #E8D0BF","j 	c #FCD9B5","k 	c #F5DB9C","l 	c #FFC94D","m 	c #FFBF46","n 	c #FFB842","o 	c #FFB140","p 	c #FFCD51","q 	c #E58345","r 	c #E3E3E3","s 	c #E78C53","t 	c #FFF2B0","u 	c #FFE36B","v 	c #FFEAA9","w 	c #DDC3B2","x 	c #DFBAA2","y 	c #FFDF9B","z 	c #FFC146","A 	c #515151","B 	c #FFB945","C 	c #FFCC52","D 	c #E6884D","E 	c #FFEB96","F 	c #FFDA4C","G 	c #F4EA9D","H 	c #D4B39D","I 	c #D09C65","J 	c #E9E8F4","K 	c #E8E190","L 	c #FFBC44","M 	c #FFBC46","N 	c #FFC54C","O 	c #FFC04B","P 	c #E58346","Q 	c #FFEA93","R 	c #FFD74B","S 	c #43AE60","T 	c #72D97F","U 	c #CD4A16","V 	c #FFBD49","W 	c #FFCA51","X 	c #E58548","Y 	c #FFE892","Z 	c #FFD44A","` 	c #D2E8CC"," .	c #FFB441","..	c #FFB543","+.	c #FFC04A","@.	c #FFBA48","#.	c #FFC750","$.	c #FFEB5A","%.	c #FFE95A","&.	c #FFE859","*.	c #FFE759","=.	c #FFE558","-.	c #FFE358",";.	c #FFE157",">.	c #FFDF56",",.	c #FFDE56","'.	c #FFE058",").	c #FFDE57","!.	c #FFD854","~.	c #E58446","                                ","                                ","  . + @ @ # $ % & *             ","  = - ; > , ' ) ! ~ {           ","  ] ^ / ( _ : < [ } | 1 2 1 3   ","  + 4 5 6 7 7 8 9 0 a b c d e f ","  ] g _ h 7 i j k l m n o p q r ","  s t u v w j x y z A A B C q r ","  D E F G H I J K L M N O C q r ","  P Q R S T U T S n A A V W q r ","  X Y Z ` S S S `  ...+.@.#.q r ","  P $.%.&.*.=.-.;.>.,.'.).!.q r ","  ~.q q q q q q q q q q q q q r ","    f r r r r r r r r r r r r f ","                                ","                                "],
    'SIM': ["16 16 100 2","  	c None",". 	c #686868","+ 	c #000000","@ 	c #F3C695","# 	c #E68A4F","$ 	c #E99662","% 	c #E99661","& 	c #E99561","* 	c #E99560","= 	c #E8935D","- 	c #F4D4AD","; 	c #AA9746","> 	c #E78B51",", 	c #FFF8C5","' 	c #FFF9D4",") 	c #FFF7CE","! 	c #FFF7CD","~ 	c #FFF5CB","{ 	c #FFF3C9","] 	c #FFF1C4","^ 	c #F4BC7D","/ 	c #E78A50","( 	c #FFF7C2","_ 	c #FFF2AB",": 	c #FFF0A4","< 	c #FFEEA1","[ 	c #FFEB9D","} 	c #FFE89A","| 	c #FFE497","1 	c #FFE8AB","2 	c #FFF5BE","3 	c #FFF0A5","4 	c #FFF3CE","5 	c #C09F7D","6 	c #C2A794","7 	c #F8E8B8","8 	c #FFDB83","9 	c #FFF5BD","0 	c #FEF0C5","a 	c #E8D0BF","b 	c #FCD9B5","c 	c #F5DB9C","d 	c #FFC94D","e 	c #E78C53","f 	c #FFF2B0","g 	c #FFE36B","h 	c #FFEAA9","i 	c #DDC3B2","j 	c #DFBAA2","k 	c #FFDF9B","l 	c #FFC146","m 	c #515151","n 	c #FFB945","o 	c #FFCC52","p 	c #E58345","q 	c #E3E3E3","r 	c #E6884D","s 	c #FFEB96","t 	c #FFDA4C","u 	c #F4EA9D","v 	c #D4B39D","w 	c #D09C65","x 	c #E9E8F4","y 	c #E8E190","z 	c #FFBC44","A 	c #FFBC46","B 	c #FFC54C","C 	c #FFC04B","D 	c #E58346","E 	c #FFEA93","F 	c #FFD74B","G 	c #43AE60","H 	c #72D97F","I 	c #CD4A16","J 	c #FFB842","K 	c #FFBD49","L 	c #FFCA51","M 	c #E58548","N 	c #FFE892","O 	c #FFD44A","P 	c #D2E8CC","Q 	c #FFB441","R 	c #FFB543","S 	c #FFC04A","T 	c #FFBA48","U 	c #FFC750","V 	c #FFEB5A","W 	c #FFE95A","X 	c #FFE859","Y 	c #FFE759","Z 	c #FFE558","` 	c #FFE358"," .	c #FFE157","..	c #FFDF56","+.	c #FFDE56","@.	c #FFE058","#.	c #FFDE57","$.	c #FFD854","%.	c #E58446","&.	c #EAEAEA","                  . . . .       ","                  . + + + .     ","                  . + + + + .   ","                  . + + + + + . ","@ # $ $ % & * = - . + ; ; ; + . ","> , ' ) ! ~ { ] ^ . + + ; + + . ","/ ( _ : < [ } | 1 . + ; + ; + . ","# 2 3 4 5 5 6 7 8 . + + + + + . ","/ 9 < 0 5 a b c d . . . . . . . ","e f g h i b j k l m m n o p q   ","r s t u v w x y z A B C o p q   ","D E F G H I H G J m m K L p q   ","M N O P G G G P Q R S T U p q   ","D V W X Y Z `  ...+.@.#.$.p q   ","%.p p p p p p p p p p p p p q   ","  &.q q q q q q q q q q q q &.  "],
    'ME': ["16 16 137 2","  	c None",". 	c #B2B5B5","+ 	c #BBBBBB","@ 	c #C9CBCC","# 	c #CDD0D3","$ 	c #CDD0D4","% 	c #B9B8B9","& 	c #CBCECE","* 	c #988C53","= 	c #AEA34F","- 	c #9F8A29","; 	c #969698","> 	c #D0D2D6",", 	c #AA9746","' 	c #FFF697",") 	c #F6DB4E","! 	c #8D8E8D","~ 	c #F3C695","{ 	c #E68A4F","] 	c #E99662","^ 	c #E99661","/ 	c #E99561","( 	c #E99560","_ 	c #E8935D",": 	c #F4D4AD","< 	c #CBCBCE","[ 	c #000000","} 	c #B9B27D","| 	c #8D8E8F","1 	c #E78B51","2 	c #FFF8C5","3 	c #FFF9D4","4 	c #FFF7CE","5 	c #FFF7CD","6 	c #FFF5CB","7 	c #FFF3C9","8 	c #FFF1C4","9 	c #F4BC7D","0 	c #EDC9A6","a 	c #C9CAC9","b 	c #A0A0A0","c 	c #A1A1A1","d 	c #919193","e 	c #E78A50","f 	c #FFF7C2","g 	c #FFF2AB","h 	c #FFF0A4","i 	c #FFEEA1","j 	c #FFEB9D","k 	c #FFE89A","l 	c #FFE497","m 	c #FFE8AB","n 	c #F3B776","o 	c #A5A7A7","p 	c #B9BABB","q 	c #FFF5BE","r 	c #FFF0A5","s 	c #FFF3CE","t 	c #C09F7D","u 	c #C2A794","v 	c #F8E8B8","w 	c #FFDB83","x 	c #FFDE97","y 	c #B6B7B6","z 	c #C2C3C2","A 	c #BEC0BD","B 	c #B7B9B9","C 	c #BBBDBD","D 	c #8A8B89","E 	c #FFF5BD","F 	c #FEF0C5","G 	c #E8D0BF","H 	c #FCD9B5","I 	c #F5DB9C","J 	c #FFC94D","K 	c #FFBF46","L 	c #D89E3F","M 	c #8E8F8E","N 	c #8A8B8A","O 	c #D3D4D3","P 	c #E78C53","Q 	c #FFF2B0","R 	c #FFE36B","S 	c #FFEAA9","T 	c #DDC3B2","U 	c #DFBAA2","V 	c #FFDF9B","W 	c #FFC146","X 	c #515151","Y 	c #FFB945","Z 	c #FFCC52","` 	c #E58345"," .	c #E3E3E3","..	c #E6884D","+.	c #FFEB96","@.	c #FFDA4C","#.	c #F4EA9D","$.	c #D4B39D","%.	c #D09C65","&.	c #E9E8F4","*.	c #E8E190","=.	c #FFBC44","-.	c #FFBC46",";.	c #FFC54C",">.	c #FFC04B",",.	c #E58346","'.	c #FFEA93",").	c #FFD74B","!.	c #43AE60","~.	c #72D97F","{.	c #CD4A16","].	c #FFB842","^.	c #FFBD49","/.	c #FFCA51","(.	c #E58548","_.	c #FFE892",":.	c #FFD44A","<.	c #D2E8CC","[.	c #FFB441","}.	c #FFB543","|.	c #FFC04A","1.	c #FFBA48","2.	c #FFC750","3.	c #FFEB5A","4.	c #FFE95A","5.	c #FFE859","6.	c #FFE759","7.	c #FFE558","8.	c #FFE358","9.	c #FFE157","0.	c #FFDF56","a.	c #FFDE56","b.	c #FFE058","c.	c #FFDE57","d.	c #FFD854","e.	c #E58446","f.	c #EAEAEA","                            .   ","                    + @ # $ %   ","                    & * = - . ; ","                    > , ' ) . ! ","~ { ] ] ^ / ( _ :   < [ } [ . | ","1 2 3 4 5 6 7 8 9 0 a b c d . ! ","e f g h i j k l m n a [ o [ p | ","{ q r s t t u v w x y z A B C D ","e E i F t G H I J K L M ! ! N O ","P Q R S T H U V W X X Y Z `  .  ","..+.@.#.$.%.&.*.=.-.;.>.Z `  .  ",",.'.).!.~.{.~.!.].X X ^./.`  .  ","(._.:.<.!.!.!.<.[.}.|.1.2.`  .  ",",.3.4.5.6.7.8.9.0.a.b.c.d.`  .  ","e.` ` ` ` ` ` ` ` ` ` ` ` `  .  ","  f. . . . . . . . . . . . .f.  "],
    'CALLS': ["16 16 93 2","  	c None",". 	c #B6B7B6","+ 	c #5B5C5B","@ 	c #B6B8B6","# 	c #CFCFCF","$ 	c #F2F4F2","% 	c #CAC5B9","& 	c #CFD1CF","* 	c #A79E6B","= 	c #AA9E5C","- 	c #C0B76A","; 	c #B8AD5C","> 	c #9B8C55",", 	c #A3A5A3","' 	c #976E20",") 	c #6C5A04","! 	c #F3EAB1","~ 	c #FCF5A5","{ 	c #F6E984","] 	c #988224","^ 	c #956200","/ 	c #A07729","( 	c #986500","_ 	c #966D20",": 	c #CFD0CF","< 	c #645604","[ 	c #F3DD83","} 	c #FCE474","| 	c #F1D550","1 	c #8F7A08","2 	c #ECB900","3 	c #E5BD28","4 	c #F0BD00","5 	c #CFCECF","6 	c #786718","7 	c #80701B","8 	c #88771A","9 	c #7D7018","0 	c #C69200","a 	c #C69B28","b 	c #C79100","c 	c #915B00","d 	c #935D00","e 	c #935E00","f 	c #946000","g 	c #F5F7F5","h 	c #F2F3F2","i 	c #EBECEB","j 	c #EDEEEF","k 	c #EBEBEC","l 	c #A4A6A4","m 	c #D8B134","n 	c #F4F5F5","o 	c #FFFFFF","p 	c #939593","q 	c #ACACAC","r 	c #BEBEBE","s 	c #F4E190","t 	c #FFC800","u 	c #FFC900","v 	c #FFCE00","w 	c #FFE784","x 	c #F4CA28","y 	c #FFCC00","z 	c #88888C","A 	c #A4A5A4","B 	c #FFCA00","C 	c #F4CC2A","D 	c #FFD100","E 	c #F4CC28","F 	c #575857","G 	c #545755","H 	c #575958","I 	c #565856","J 	c #FFCD00","K 	c #936000","L 	c #FFD310","M 	c #E3CE90","N 	c #FFF8CC","O 	c #FFD300","P 	c #FFD400","Q 	c #935F00","R 	c #FFE33E","S 	c #FFEB3A","T 	c #FFE500","U 	c #FFE700","V 	c #966000","W 	c #FFFFD5","X 	c #FFFFCF","Y 	c #FFFF00","Z 	c #7E5300","` 	c #5D3A00"," .	c #795000","            . +                 ","    @ @ @ . . +                 ","  # $ $ $ $ % +                 ","  & * = - ; > ,                 ","' # ) ! ~ { ] , ^ / ^ (         ","_ : < [ } | 1 , 2 3 4 ^         ","_ 5 6 7 8 9 6 , 0 a b c d e f ( ","_ 5 g h i j k l m n o o o o o ( ","_ # p q p r p l o s t u u v (   ","_ # r r r r r l w x y y v v (   ","_ : p r p r z A B C y y D (     ","_ E + F G H I E y E y J J (     ","K L M N D O P P P P P P (       ","Q R o S T T T T T T U U (       ","V W X Y Y Y Y Y Y Y Y (         ","Z ` ` ` ` ` ` ` ` ` `  .        "]
}

PB = {}
for x in XPM:
    PB[x] = gtk.gdk.pixbuf_new_from_xpm_data( XPM[x] )

class Pammu:


    ###################################################################
    #
    #   Menu and action bar
    #

    def create_menu(self, window, vbox):

        # {action name/sort name} {menu} {name} {stock icon/show in toolbar} {function} {hint}
        menu_items = (
            ( "Phone",  "menu",   _("_Phone"),       None,                    None, 			None, None ),
            ( "Conn",   "Phone",  _("_Connect"),     gtk.STOCK_CONNECT,       self.connect, 	None, _("Connect to phone") ),
            ( "Disc",   "Phone",  _("_Disconnect"),  gtk.STOCK_DISCONNECT,    self.disconnect,  None, _("Disconnecting") ),
            ( "Back",   "Phone",  _("_Backup"),      None,                    self.box_future, 	None, _("Create a backup of phone database") ),
            ( "Rest",   "Phone",  _("_Restore"),     None,                    self.box_future, 	None, _("Restore phone database from a backup") ),
            ( "Wiz",    "Phone",  _("Phone _wizard"),gtk.STOCK_NETWORK,       self.box_future,  None, _("Phone setup wizard") ),
            ( "Pref",   "Phone",  _("_Preferences"), gtk.STOCK_PREFERENCES,   self.box_setup,   None, _("Settings of software") ),
            ( "Quit",   "Phone",  _("_Quit"),        gtk.STOCK_QUIT,          gtk.main_quit, 	None, _("Exit from software") ),

            ( "Down",   "menu",  _("_Downloads"),        None,              None,            None,             None ),
            ( "Info",   "Down",  _("_Info"),             gtk.STOCK_INFO,    self.read_info,  None,             _("Read informations from phone") ),
            ( "Cldr",   "Down",  _("_Calendar"),         None,              self.read_data,  ['MEETING'],      _("Read calendar from phone") ),
            ( "Todos",  "Down",  _("_Todos"),            None,              self.read_data,  ['MEMO'],         _("Read todos from phone") ),
            ( "Msgs",   "Down",  _("_Messages"),         None,              self.read_data,  ['MT','FD','VM'], _("Read messages from phone") ),
            ( "Cal",    "Down",  _("_Calls"),            None,              self.read_data,  ['DC','RC','MC'], _("Read calls from phone") ),
            ( "C-SM",   "Down",  _("Contacts (_SIM)"),   None,              self.read_data,  ['SM'],           _("Read contacts from SIM") ),
            ( "C-ME",   "Down",  _("Contacts (_Phone)"), None,              self.read_data,  ['ME'],           _("Read contacts from phone") ),
            ( "All",    "Down",  _("_All"),              gtk.STOCK_CONVERT, self.read_data,  ['MEETING','MEMO','ME','SM','ON','DC','RC','MC','MT','FD','VM'], _("Read all from phone") ),

            ( "Create", "menu",    _("_Create"),   None,         	  None, 			None, None ),
            ( "Msg",    "Create",  _("_Message"),  gtk.STOCK_EDIT,    self.write_data, 	"SMS",      _("Write a new SMS") ),
            ( "Cont",   "Create",  _("_Contact"),  gtk.STOCK_ADD,     self.write_data,	"CONTACT",  _("Store a new contacts") ),
            ( "Todo",   "Create",  _("_Todo"),     gtk.STOCK_EXECUTE, self.write_data,  "TODO",     _("Store a new todo") ),
            ( "Event",  "Create",  _("_Event"),    gtk.STOCK_INDEX,   self.write_data,  "CALENDAR", _("Store a new calendar event") ),

            ( "Set",    "menu",    _("_Edit"),           None,           None, 			      None, None ),
            ( "Time",   "Set",     _("_Sync Time"),      None,           self.box_future, 	  None, _("Syncing the time") ),
            ( "File",   "Set",     _("Send _file"),      None,           self.box_future, 	  None, _("Send a file") ),
            ( "Clear",  "Set",     _("Clear"),           None,           None, 	              None, None ),

            ( "cTodo",  "Clear",   _("Todos"),           None, self.clear_data, ['MEMO'],               _("Clear all of todos") ),
            ( "cCall",  "Clear",   _("Calls"),           None, self.clear_data, ['ON','DC','RC','MC'],  _("Clear all of calls") ),
            ( "cEvnt",  "Clear",   _("Calendar"),        None, self.clear_data, ['MEETING'],                _("Clear all of calendar events") ),
            ( "cCnS",   "Clear",   _("Contact (SIM)"),   None, self.clear_data, ['SM'],                 _("Clear all of contact from SIM") ),
            ( "cCnM",   "Clear",   _("Contact (Phone)"), None, self.clear_data, ['ME'],                 _("Clear all of contact from phone") ),
            ( "cSMS",   "Clear",   _("SMS"),             None, self.clear_data, ['MT','FD','VM'],       _("Clear all of SMS") ),
            ( "cAll",   "Clear",   _("All data"),        None, self.clear_data, ['MEETING','MEMO','ME','SM','ON','DC','RC','MC','MT','FD','VM'], _("Clear all data") ),

            ( "Data",   "menu",   _("_Data"),    None, None,           None,    None ),
            ( "Imp",    "Data",   _("_Import"),  None, self.db_import, None,    _("Import the phone database from PC") ),
            ( "Exp",    "Data",   _("_Export"),  None, self.db_export, None,    _("Exort the phone database to PC") ),

            ( "Help",   "menu",   _("_Help"),           None,            None, 				 None,                  None ),
            ( "Hlp",    "Help",   _("_Context"),        gtk.STOCK_HELP,  self.url_open,     __helpurl__,           _("Help for using the software") ),
            ( "PDB",    "Help",   _("Phone _database"), None,            self.url_open,     __phonedatabaseurl__,  _("Gammu phone database on the net") ),
            ( "LP",     "Help",   _("_Launchpad"),      None,            self.url_open, 	__launchpadurl__,      _("Support database on the net") ),
            ( "Supp",   "Help",   _("Error _report"),   None,            self.url_open, 	__errorurl__,          _("Support database on the net") ),
            ( "About",  "Help",   _("_About"),   	    gtk.STOCK_ABOUT, self.box_about, 	 None,                 _("About the software") )
        )


        # Create action group
        accelgroup = gtk.AccelGroup()
        window.add_accel_group(accelgroup)
        actiongroup = gtk.ActionGroup('BasicAction')

        # Create menubar
        menubar = gtk.MenuBar()
        vbox.pack_start(menubar, False)

        # Create Toolbar
        toolbar = gtk.Toolbar()
        toolbar.set_style(gtk.TOOLBAR_ICONS)
        vbox.pack_start(toolbar, False)

        # Create menu and toolbar items from setup (menu_items)
        self.action = {}
        self.menu = { "menu": menubar }
        chk = False
        for item in menu_items:

            # Create menu item
            self.action[item[0]] = gtk.Action( item[0], item[2], item[6], item[3] )
            actiongroup.add_action( self.action[item[0]] )
            menuitem = self.action[item[0]].create_menu_item()
            self.menu[item[1]].append(menuitem)

            # Create menu group
            if item[4] is None:
                self.menu[item[0]] = gtk.Menu()
                menuitem.set_submenu( self.menu[item[0]] )

                # Create toolbar separator
                if chk:
                    separator = gtk.SeparatorToolItem()
                    toolbar.insert(separator, -1)
                    chk = False

            # Create toolbar item
            else:
                self.action[item[0]].connect('activate', item[4], item[5])
                self.action[item[0]].set_accel_group(accelgroup)
                if not item[3] is None:
                    toolitem = self.action[item[0]].create_tool_item()
                    toolbar.insert(toolitem, -1)
                    chk = True


    ###################################################################
    #
    #   Feature list
    #

    def create_sidebar(self, hbox):

        # Data of list on the left side
        list_items = (
            ( None,          _("Phone"),     PB['PHONE'],    0 ),
            ( _("Phone"),    _("Calendar"),  PB['CALENDAR'], 1 ),
            ( _("Phone"),    _("Todos"),     PB['TODO'],     2 ),
            ( _("Phone"),    _("SMS"),       PB['FOLDER'],   5 ),
            ( _("SMS"),      _("Incoming"),  PB['TODO'],     5 ),
            ( _("SMS"),      _("Sent"),      PB['TODO'],     5 ),
            ( _("SMS"),      _("Unsent"),    PB['TODO'],     5 ),
            ( _("SMS"),      _("Draft"),     PB['TODO'],     5 ),
            ( _("Phone"),    _("Calls"),     PB['CALLS'],    3 ),
            ( _("Calls"),    _("Outgoing"),  PB['TODO'],     3 ),
            ( _("Calls"),    _("Received"),  PB['TODO'],     3 ),
            ( _("Calls"),    _("Missed"),    PB['TODO'],     3 ),
            ( _("Phone"),    _("Contacts"),  PB['CONTACT'],  4 ),
            ( _("Contacts"), _("SIM"),       PB['SIM'],      4 ),
            ( _("Contacts"), _("Phone "),    PB['ME'],       4 )
            #( _("Phone"),    _("Files"),     PB['FILE'],     6 ), !!!
            #( None,          _("Computer"),  PB['PHONE'],    0 ),
            #( _("Computer"), _("Calendar "), PB['CALENDAR'], 1 ),
            #( _("Computer"), _("Todos "),    PB['TODO'],     2 ),
            #( _("Computer"), _("Contacts "), PB['CONTACT'],  4 )
        )

        # Create data of list in left side
        tree_store = gtk.TreeStore( gtk.gdk.Pixbuf, gobject.TYPE_STRING, gobject.TYPE_BOOLEAN, int )
        items = {}
        for item in list_items:
            if item[0] is None: items[item[1]] = tree_store.append( None, ( item[2], item[1], None, item[3] ) )
            else: items[item[1]] = tree_store.append( items[item[0]], (item[2], item[1], None, item[3] ) )

        # Create treeview
        self.view = gtk.TreeView( tree_store )
        self.view.connect( 'cursor-changed', self.event_feature )
        self.view.set_property( "enable-tree-lines", True )
        self.view.expand_all()

        # Create renderers
        renderertext = gtk.CellRendererText()
        renderertext.set_property( 'editable', False )
        renderertoggle = gtk.CellRendererToggle()
        renderertoggle.set_property( 'activatable', True )
        renderertoggle.connect( 'toggled', self.event_toggle, tree_store )
        rendererpix = gtk.CellRendererPixbuf()

        # Create columns
        column0 = gtk.TreeViewColumn( _("Section"), rendererpix, pixbuf=0 )
        column0.set_min_width( 142 )
        column0.pack_start( renderertext, True )
        column0.add_attribute( renderertext, 'text', 1 )
        self.view.append_column( column0 )
        column1 = gtk.TreeViewColumn( _("Sync"), renderertoggle )
        column1.add_attribute( renderertoggle, "active", 2 )
        #self.view.append_column( column1 ) !!!

        # Create frame
        frame = gtk.Frame()
        frame.add( self.view )
        hbox.pack_start( frame, False )


    def create_list(self, typ):

        # Create list
        LISTS[typ]['STORE'] = gtk.ListStore( *([ str ] * len(LISTS[typ]['FIELDS'])) )
        list = gtk.TreeView( LISTS[typ]['STORE'] )
        list.set_border_width(4)
        list.connect( 'row-activated', self.event_list, typ )
        for x in range(len(LISTS[typ]['FIELDS'])):
            column = gtk.TreeViewColumn( _(LISTS[typ]['FIELDS'][x]) )
            if LISTS[typ]['WIDTHS'][x] > 0:
                list.append_column( column )
                column.set_min_width( LISTS[typ]['WIDTHS'][x] )
                column.set_sizing(gtk.TREE_VIEW_COLUMN_AUTOSIZE)
                renderer = gtk.CellRendererText()
                column.pack_start( renderer, True )
                column.set_attributes( renderer, text=x )

        return list


    ###################################################################
    #
    #   Events
    #

    def event_feature(self, treeview):

        # Select choiced notebook page of main frame
        path, column = treeview.get_cursor()
        if not column: return
        model = treeview.get_model()
        self.notebook.set_current_page( model.get_value(model.get_iter(path), 3) )


    def event_toggle(self, cell, path, model):

        # Switch the checkbox
        model[path][2] = not model[path][2]


    def event_list(self, treeview, path, column, typ):

        if not column: return
        model = treeview.get_model()

        defaults = []
        for x in range(len(model[0])):
            defaults += [ model.get_value(model.get_iter(path), x) ]

        self.write_data(typ=typ, defs=defaults)


    def event_insert(self, line):

        # Precorrections and defaults
        if 'Type' not in line:
            if 'MemoryType' in line: line['Type'] = line['MemoryType']
            else: line['Type'] = 'ON'
        if line['Type'] not in DATATYPE: line['Type'] = 'ON'
        if 'Name' not in line: line['Name'] = "(%s)" % _("unknown")
        for x in LISTS[DATATYPE[line['Type']]['TABLE']]['FIELDS']:
            if not x in line: line[x] = ''

        # Search subdata
        if 'Entries' in line:
            for data in line['Entries']:
                if data['Type'].upper().find('NAME') != -1: line['Name'] = data['Value']
                elif data['Type'].upper().find('NUMBER_') != -1: line['Number'] = data['Value']
                elif data['Type'].upper().find('START_DATE') != -1: line['StartDate'] = data['Value'].strftime("%d/%m/%Y %H:%M")
                elif data['Type'].upper().find('END_DATE') != -1: line['EndDate'] = data['Value'].strftime("%d/%m/%Y %H:%M")
                elif data['Type'].upper().find('DATE') != -1: line['Date'] = data['Value'].strftime("%d/%m/%Y %H:%M")
                elif data['Type'].upper() == 'TEXT': line['Text'] = data['Value']
                elif data['Type'].upper() == 'COMPLETED': line['Completed'] = _("yes")
                else: line[data['Type']] = data['Value']

        # Store data
        list = []
        for x in LISTS[DATATYPE[line['Type']]['TABLE']]['FIELDS']: list += [ line[x] ]
        LISTS[DATATYPE[line['Type']]['TABLE']]['STORE'].append( list )
        self.phone_data[line['Type']].append( line )

        # for debug and discover new phones !!!
        print
        for x in line: print "%s = '%s'" % (x,line[x])


    def event_day(self, *args):
        year, month, day = self.calendar.get_date()
        date = time.localtime( time.mktime((year, month+1, day, 0, 0, 0, 0, 0, -1)) )[0:5]
        self.calendar.clear_marks()

        # Data of the day
        list_items = []
        for x in range(24):
            list_items.append( [ None, "%2d:00" % x, PB['CALENDAR'], 1 ] )
        for line in self.phone_data['MEETING']:
            t = time.strptime(line['StartDate'], "%d/%m/%Y %H:%M")[0:5]
            if t[0:2] == date[0:2]:
                self.calendar.mark_day( t[2] )
            if t[0:3] == date[0:3]:
                hour = "%2d:00" % t[3]
                id = "%s (%s)" % (line['Text'][:20], line['Location'])
                list_items.append( [ "%2d:00" % t[3], id, PB['FOLDER'], 1 ] )
                for data in line:
                    if (type(line[data]) not in (list, dict)) and (data not in ('Location','Type','Name')):
                        list_items.append( [ id, "%s: %s" % (data, line[data]), PB['TODO'], 1 ] )

        # Refresh data of list
        self.day.get_model().clear()
        items = {}
        for item in list_items:
            if item[0] is None: items[item[1]] = self.day.get_model().append( None, ( item[2], item[1], None, item[3] ) )
            else: items[item[1]] = self.day.get_model().append( items[item[0]], (item[2], item[1], None, item[3] ) )


    ###################################################################
    #
    #   Main window
    #

    def __init__(self):

        # Load config
        self.phone_data = {'ME':[],'SM':[],'ON':[],'DC':[],'RC':[],'MC':[],'MT':[],'FD':[],'VM':[],'MEMO':[],'MEETING':[]}
        self.pbar = {}
        self.sm = None
        self.setup_load()

        # Create window
        self.window = gtk.Window( gtk.WINDOW_TOPLEVEL )
        self.window.connect( "delete_event", lambda w,t: not w.hide() )
        self.window.connect( "destroy", lambda w: gtk.main_quit() )
        self.window.set_title( "%s %s" % (__fullname__, __version__) )
        self.window.set_size_request( 620, 440 )
        self.window.set_position( gtk.WIN_POS_CENTER )
        try: self.window.set_icon_from_file( "pammu.png" )
        except: pass

        # Set systray
        self.tray = egg.trayicon.TrayIcon( "Phone" )
        eventbox = gtk.EventBox()
        self.tray.add(eventbox)
        eventbox.connect( "button_press_event", lambda w,t: self.window.present() )
        image = gtk.Image()
        image.set_from_stock( gtk.STOCK_DIALOG_INFO, gtk.ICON_SIZE_SMALL_TOOLBAR )
        eventbox.add(image)
        self.tray.show_all()

        # Create menu and toolbar
        main_vbox = gtk.VBox()
        self.window.add( main_vbox )
        main_vbox.set_border_width(1)
        self.create_menu( self.window, main_vbox )

        # Create list in left side
        hbox = gtk.HBox()
        main_vbox.pack_start( hbox , True )
        self.create_sidebar( hbox )

        # Notebook
        self.notebook = gtk.Notebook()
        hbox.pack_start(self.notebook, True)

        ###############################################################
        #
        #   0 - Info
        #

        # Labels of info frame
        labels = (
            ( _("Connection"),   "CONNECTION" ),
            ( _("Model"),        "TYPE" ),
            ( _("Device"),       "DEVICE" ),
            ( _("Manufacturer"), "MANUFACTURER" ),
            ( _("Model"),        "MODEL" ),
            ( _("IMEI"),         "IMEI" ),
            ( _("Firmware"),     "FIRMWARE" )
        )

        # Create data of table
        self.info = {}
        table = gtk.Table(7, 3, True)
        table.show()
        for y in range(7):
            for x in range(2):
                label = gtk.Label("%s:" % labels[y][0])
                if x == 0: label.set_alignment(1.0, 0.5)
                else: self.info[labels[y][1]] = label
                table.attach(label,x,x*2+1,y,y+1)

        # Frame
        frame = gtk.Frame( _("Informations") )
        frame.set_border_width(6)
        frame.add(table)
        frame.show()
        self.notebook.append_page(frame, None)

        ###############################################################
        #
        #   1 - Calendar
        #

        # Main page
        box0 = gtk.HBox()
        self.notebook.append_page(box0, None)
        LISTS['CALENDAR']['PAGE'] = self.notebook.page_num( box0 )

        # Calendar frame
        box = gtk.VBox()
        frame = gtk.Frame( _("Calendar") )
        frame.set_border_width(4)
        box0.pack_start(box, True)

        # Create calendar
        self.calendar = gtk.Calendar()
        #gtk.CALENDAR_WEEK_START_MONDAY Setupba !!!
        self.calendar.display_options(gtk.CALENDAR_SHOW_HEADING | gtk.CALENDAR_SHOW_DAY_NAMES | gtk.CALENDAR_SHOW_WEEK_NUMBERS)
        frame.add(self.calendar)
        box.pack_start(frame, False)
        self.calendar.connect("day_selected", self.event_day)

        # Create scrolled wondow with list
        frame = gtk.Frame( _("Memos") )
        frame.set_border_width(4)
        scrolled_window = gtk.ScrolledWindow()
        scrolled_window.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
        scrolled_window.add( self.create_list('CALENDAR') )
        frame.add(scrolled_window)
        box.pack_start(frame, True)

        # Create the ProgressBar
        box = gtk.VBox()
        box0.pack_start(box, True)
        frame = gtk.Frame( _("Status") )
        frame.set_border_width(4)
        pbox = gtk.HBox()
        ppbox = gtk.VBox()
        ppbox.pack_start(pbox, True, True, 4)
        frame.add(ppbox)
        DATATYPE['MEETING']['PBAR'] = gtk.ProgressBar()
        DATATYPE['MEETING']['PBAR'].set_text( _("unknown") )
        DATATYPE['MEETING']['PBAR'].set_fraction(0.0)
        pbox.pack_start(DATATYPE['MEETING']['PBAR'], True, True, 4)
        button = gtk.Button( "↓" )
        button.connect('clicked', self.read_data, ['MEETING'])
        pbox.pack_start(button, False, False, 4)
        box.pack_start(frame, False, False, 4)

        # Day data frame
        frame = gtk.Frame( _("Selected day") )
        frame.set_border_width(4)
        box.pack_start(frame, True)

        # Create data of list in left side
        tree_store = gtk.TreeStore( gtk.gdk.Pixbuf, gobject.TYPE_STRING, gobject.TYPE_BOOLEAN, int )

        # Create treeview
        self.day = gtk.TreeView( tree_store )
        #self.day.connect( 'cursor-changed', self.event_feature )
        self.day.set_property( "enable-tree-lines", True )
        self.day.expand_all()

        # Create renderers
        renderertext = gtk.CellRendererText()
        renderertext.set_property( 'editable', False )
        renderertoggle = gtk.CellRendererToggle()
        renderertoggle.set_property( 'activatable', True )
        renderertoggle.connect( 'toggled', self.event_toggle, tree_store )
        rendererpix = gtk.CellRendererPixbuf()

        # Create columns
        column0 = gtk.TreeViewColumn( _("Data"), rendererpix, pixbuf=0 )
        column0.set_min_width( 142 )
        column0.pack_start( renderertext, True )
        column0.add_attribute( renderertext, 'text', 1 )
        self.day.append_column( column0 )
        column1 = gtk.TreeViewColumn( _("Sync"), renderertoggle )
        column1.add_attribute( renderertoggle, "active", 2 )
        #self.day.append_column( column1 ) !!!

        # Scrolling
        scrolled_window = gtk.ScrolledWindow()
        scrolled_window.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
        scrolled_window.add( self.day )
        frame.add( scrolled_window )

        # Insert actual data
        self.event_day()


        ###############################################################
        #
        #   2 - Todos
        #

        # Frame
        frame = gtk.Frame( _("Todos") )
        frame.set_border_width(4)
        self.notebook.append_page(frame, None)
        LISTS['TODO']['PAGE'] = self.notebook.page_num( frame )
        box = gtk.VBox()
        frame.add(box)

        # Create the ProgressBar
        pbox = gtk.HBox()
        box.pack_start(pbox, False, False, 4)
        DATATYPE['MEMO']['PBAR'] = gtk.ProgressBar()
        DATATYPE['MEMO']['PBAR'].set_text( _("unknown") )
        DATATYPE['MEMO']['PBAR'].set_fraction(0.0)
        pbox.pack_start(DATATYPE['MEMO']['PBAR'], True, True, 2)
        button = gtk.Button( _("Refresh") )
        button.connect('clicked', self.read_data, ['MEMO'])
        pbox.pack_start(button, False, False, 2)

        # Create scrolled wondow with list
        scrolled_window = gtk.ScrolledWindow()
        scrolled_window.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
        box.pack_start(scrolled_window, True)
        scrolled_window.add( self.create_list('TODO') )


        ###############################################################
        #
        #   3 - Calls
        #

        # Frame
        frame = gtk.Frame( _("Calls") )
        frame.set_border_width(4)
        self.notebook.append_page(frame, None)
        LISTS['CALL']['PAGE'] = self.notebook.page_num( frame )
        box = gtk.VBox()
        frame.add(box)

        # Create the ProgressBar
        pbox = gtk.HBox()
        box.pack_start(pbox, False, False, 4)
        for x in ('DC','RC','MC'):
            DATATYPE[x]['PBAR'] = gtk.ProgressBar()
            DATATYPE[x]['PBAR'].set_text( _("unknown") )
            DATATYPE[x]['PBAR'].set_fraction(0.0)
            pbox.pack_start(DATATYPE[x]['PBAR'], True, True, 2)
            button = gtk.Button( "↓%s" % x )
            button.connect('clicked', self.read_data, [x])
            pbox.pack_start(button, False, False, 2)

        # Create scrolled wondow with list
        scrolled_window = gtk.ScrolledWindow()
        scrolled_window.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
        box.pack_start(scrolled_window, True)
        scrolled_window.add( self.create_list('CALL') )


        ###############################################################
        #
        #   4 - Contacts
        #

        # Frame
        frame = gtk.Frame( _("Contacts") )
        frame.set_border_width(4)
        self.notebook.append_page(frame, None)
        LISTS['CONTACT']['PAGE'] = self.notebook.page_num( frame )
        box = gtk.VBox()
        frame.add(box)

        # Create the ProgressBar
        pbox = gtk.HBox()
        box.pack_start(pbox, False, False, 4)
        for x in ('SM','ME'):
            DATATYPE[x]['PBAR'] = gtk.ProgressBar()
            DATATYPE[x]['PBAR'].set_text( _("unknown") )
            DATATYPE[x]['PBAR'].set_fraction(0.0)
            pbox.pack_start(DATATYPE[x]['PBAR'], True, True, 2)
            button = gtk.Button( "↓%s" % x )
            button.connect('clicked', self.read_data, [x])
            pbox.pack_start(button, False, False, 2)

        # Create scrolled wondow
        scrolled_window = gtk.ScrolledWindow()
        scrolled_window.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
        box.pack_start(scrolled_window, True)
        scrolled_window.add( self.create_list('CONTACT') )


        ###############################################################
        #
        #   5 - SMS
        #

        sbox = gtk.VBox()

        # Frame of list
        frame = gtk.Frame( _("Todos") )
        frame.set_border_width(4)
        sbox.pack_start(frame, True)
        self.notebook.append_page(sbox, None)
        LISTS['SMS']['PAGE'] = self.notebook.page_num( sbox )
        box = gtk.VBox()
        frame.add(box)

        # Create the ProgressBar
        pbox = gtk.HBox()
        box.pack_start(pbox, False, False, 4)
        for x in ('MT','FD','VM'):
            DATATYPE[x]['PBAR'] = gtk.ProgressBar()
            DATATYPE[x]['PBAR'].set_text( _("unknown") )
            DATATYPE[x]['PBAR'].set_fraction(0.0)
            pbox.pack_start(DATATYPE[x]['PBAR'], True, True, 2)
            button = gtk.Button( "↓%s" % x )
            button.connect('clicked', self.read_data, [x])
            pbox.pack_start(button, False, False, 2)

        # Create scrolled wondow with list
        scrolled_window = gtk.ScrolledWindow()
        scrolled_window.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
        box.pack_start(scrolled_window, True)
        scrolled_window.add( self.create_list('SMS') )

        # Frame of SMS
        frame = gtk.Frame( _("SMS") )
        frame.set_border_width(4)
        self.sms_label = gtk.Label("")
        frame.add(self.sms_label)
        sbox.pack_start(frame, True)

        ###############################################################
        #
        #   6 - Files
        #

        frame = gtk.Frame( _("Files") )
        frame.set_border_width(4)
        self.notebook.append_page(frame, None)

        ###############################################################

        # Setup notebook
        self.notebook.set_show_tabs(False)
        self.notebook.set_show_border(False)
        self.notebook.set_current_page(0)

        # Status line
        self.status = gtk.Label( _("Ready to use") )
        self.status.set_property('ypad', 4)
        frame = gtk.Frame()
        frame.add(self.status)
        main_vbox.pack_start(frame, False)

        # Show window
        self.clear_info()
        self.window.show_all()
        self.view.grab_focus()


    ###################################################################
    #
    #   Phone connection
    #

    def connect(self, *args):

        self.status.set_text( _("Connecting ...") )

        if self._cfg['Model'] == 'auto': self._cfg['Model'] = ''

        try:
            self.sm = gammu.StateMachine()
            self.sm.SetConfig(0, self._cfg)
            self.sm.Init()
        except Exception, e:
            self.box_error( e[0]['Text'] )
            self.status.set_text( e[0]['Text'] )
            self.clear_info()
            self.sm = None
            return False

        self.read_info()
        self.status.set_text( _("Phone is connected") )
        return True

    def disconnect(self, *args):

        self.status.set_text( _("Disconnecting ...") )

        if not self.sm:
            self.status.set_text( _("Phone is not connected") )
            return

        try:
            self.sm.Terminate()
        except Exception, e:
            self.box_error( e[0]['Text'] )
            self.status.set_text( e[0]['Text'] )
            return

        self.clear_info()
        self.sm = None
        self.status.set_text( _("Phone is disconnected") )


    def clear_info(self, *args):

        self.info['CONNECTION'].set_text( self._cfg['Connection'] )
        self.info['TYPE'].set_text( self._cfg['Model'] )
        self.info['DEVICE'].set_text( self._cfg['Device'] )
        if self._cfg['Model'] == '': self.info['TYPE'].set_text( 'auto' )
        self.info['MANUFACTURER'].set_text( _("unknown") )
        self.info['MODEL'].set_text( _("unknown") )
        self.info['IMEI'].set_text( _("unknown") )
        self.info['FIRMWARE'].set_text( _("unknown") )

        for x in ['MEMO']:
            DATATYPE[x]['PBAR'].set_text( _("unknown") )
            DATATYPE[x]['PBAR'].set_fraction(0.0)


    ###################################################################
    #
    #   Read data from phone
    #

    def read_info(self, *args):

        self.status.set_text( _("Read information ...") )

        self.info['CONNECTION'].set_text( self._cfg['Connection'] )
        self.info['TYPE'].set_text( self._cfg['Model'] )
        self.info['DEVICE'].set_text( self._cfg['Device'] )
        if self._cfg['Model'] == '': self.info['TYPE'].set_text( 'auto' )

        # Is the phone connected?
        if not self.sm:
            if not self.connect(): return

        try:
            Manufacturer = self.sm.GetManufacturer()
            Model = self.sm.GetModel()
            IMEI = self.sm.GetIMEI()
            Firmware = self.sm.GetFirmware()
        except Exception, e:
            self.box_error( e[0]['Text'] )
            self.status.set_text( e[0]['Text'] )
            self.clear_info()
            return

        self.info['MANUFACTURER'].set_text( Manufacturer )
        self.info['MODEL'].set_text( '%s (%s)' % (Model[0], Model[1]) )
        self.info['IMEI'].set_text( IMEI )
        self.info['FIRMWARE'].set_text( Firmware[0] )

        self.status.set_text( _("Information readed") )


    def read_data(self, w=None, types=[]):

        for typ in types:
            self.notebook.set_current_page(LISTS[DATATYPE[typ]['TABLE']]['PAGE'])

            # Is the phone connected?
            if not self.sm:
                if not self.connect(): return

            # Set status
            try:
                if typ in ['MEMO','MEETING']: exec( "status = self.sm.%s()" % LISTS[DATATYPE[typ]['TABLE']]['COMMANDS']['STATUS'] )
                else: exec( "status = self.sm.%s(Type=typ)" % LISTS[DATATYPE[typ]['TABLE']]['COMMANDS']['STATUS'] )
            except (gammu.ERR_NOTSUPPORTED, gammu.ERR_NOTIMPLEMENTED):
                status = { 'Free': 0, 'Used': 500 }
            percent = float(status['Used']) / ( float(status['Free']) + float(status['Used']) )
            if DATATYPE[typ]['PBAR']:
                DATATYPE[typ]['PBAR'].set_fraction(percent)
                DATATYPE[typ]['PBAR'].set_text( _("%d%% (Used: %s/%s)") % (percent*100, status['Used'], status['Free']+status['Used']) )
            if status['Used'] == 0: return

            # Clean database
            LISTS[DATATYPE[typ]['TABLE']]['STORE'].clear()
            self.phone_data[typ] = []

            # Read data from phone
            try:
                if typ in ['MEMO','MEETING']: exec( "data = self.sm.%s(Start = True)" % LISTS[DATATYPE[typ]['TABLE']]['COMMANDS']['GETNEXT'] )
                elif typ in ['MT','FD','VM']: exec( "data = self.sm.%s(Folder=0, Start = True)" % LISTS[DATATYPE[typ]['TABLE']]['COMMANDS']['GETNEXT'] )
                else: exec( "data = self.sm.%s(Type=typ, Start = True)" % LISTS[DATATYPE[typ]['TABLE']]['COMMANDS']['GETNEXT'] )
                x = 1
                while True:
                    try:
                        if type(data) == list: data = data[0]
                        self.event_insert( data )
                        if x == status['Used']: break
                        if typ in ['MEMO','MEETING']: exec( "data = self.sm.%s(Location = data['Location'])" % LISTS[DATATYPE[typ]['TABLE']]['COMMANDS']['GETNEXT'] )
                        elif typ in ['MT','FD','VM']: exec( "data = self.sm.%s(Folder=0, Location = data['Location'])" % LISTS[DATATYPE[typ]['TABLE']]['COMMANDS']['GETNEXT'] )
                        else: exec( "data = self.sm.%s(Type=typ, Location = data['Location'])" % LISTS[DATATYPE[typ]['TABLE']]['COMMANDS']['GETNEXT'] )
                        x += 1
                    except (gammu.ERR_EMPTY, gammu.ERR_INVALIDLOCATION):
                        break

            except (gammu.ERR_NOTSUPPORTED, gammu.ERR_NOTIMPLEMENTED):
                total, used = status['Free'] + status['Used'], status['Used']
                for x in range(total):
                    try:
                        if typ in ['MEMO','MEETING']: exec( "data = self.sm.%s(x+1)" % LISTS[DATATYPE[typ]['TABLE']]['COMMANDS']['GETID'] )
                        elif typ in ['MT','FD','VM']: exec( "data = self.sm.%s(Folder=0, Location=x+1)" % LISTS[DATATYPE[typ]['TABLE']]['COMMANDS']['GETID'] )
                        else: exec( "data = self.sm.%s(typ,x+1)" % LISTS[DATATYPE[typ]['TABLE']]['COMMANDS']['GETID'] )
                        used -= 1
                        self.event_insert( data )
                    except (gammu.ERR_EMPTY, gammu.ERR_INVALIDLOCATION):
                        pass
                    if used == 0: break

        self.event_day()


    ###################################################################
    #
    #   Write data into phone
    #

    def write_data(self, w=None, typ='SMS', defs=None):

        # Pack requested data
        data = []
        for x in range( len( LISTS[typ]['FIELDS'] ) ):
            if not defs: data.append( [ LISTS[typ]['FIELDS'][x], LISTS[typ]['DEFS'][x], LISTS[typ]['TYPES'][x] ] )
            else: data.append( [ LISTS[typ]['FIELDS'][x], defs[x], LISTS[typ]['TYPES'][x] ] )

        # Dialog box
        ret, data = self.box_dialog(data)
        if ret == RET_CANCEL: return

        # Is the phone connected?
        if not self.sm:
            if not self.connect(): return

        # Delete
        data['Location'] = int(data['Location'])
        if ret == RET_DELETE:
            if data['Location'] != 0:
                if typ in ['TODO','CALENDAR']: exec( "self.sm.%s(Location = data['Location'])" % LISTS[typ]['COMMANDS']['DEL'] )
                elif typ in ['SMS']: exec( "self.sm.%s(Folder=0, Location = data['Location'])" % LISTS[typ]['COMMANDS']['DEL'] )
                else: exec( "self.sm.%s(Type=typ, Location = data['Location'])" % LISTS[typ]['COMMANDS']['DEL'] )


        if ret == RET_OK:

            print data

            # Create phone data
            if typ in ['TODO','CALENDAR']:
                pack = {
                    'Location': data['Location'],
                    'Type': data['Type'],
                    'Priority': data['Priority'],
                    'Entries': [
                        { 'Type': 'TEXT', 'Value': data['Text'] },
                        { 'Type': 'END_DATETIME', 'Value': datetime.datetime( *time.strptime(data['EndDate'], "%d/%m/%Y %H:%M")[0:5] ) },
                    ]
                }
                if data['Completed'] == 'yes': pack['Entries'].append( { 'Type': 'COMPLETED', 'Value': 1 } )
                if 'StartDate' in data: pack['Entries'].append( { 'Type': 'START_DATETIME', 'Value': datetime.datetime( *time.strptime(data['StartDate'], "%d/%m/%Y %H:%M")[0:5] ) } )

            elif typ in ['SMS']:
                pass


            else:
                pack = {
                    'Location': data['Location'],
                    'MemoryType': data['Type'],
                    'Entries': [
                        { 'Type': 'Text_Name', 'Value': data['Name'] },
                        { 'Type': 'Number_General', 'Value': data['Number'] }
                    ]
                }
                if 'Date' in data: pack['Entries'].append( { 'Type': 'Date', 'Value': datetime.datetime( *time.strptime(data['Date'], "%d/%m/%Y %H:%M")[0:5] ) } )
                if 'CallLength' in data: pack['Entries'].append( { 'Type': 'CallLength', 'Value': int(data['CallLength']) } )


            print pack
            if data['Location'] == 0:
                if typ in ['TODO','CALENDAR']: exec( "self.sm.%s(pack)" % LISTS[typ]['COMMANDS']['ADD'] )
                elif typ in ['SMS']: exec( "self.sm.%s(Folder=0, pack)" % LISTS[typ]['COMMANDS']['ADD'] )
                else: exec( "self.sm.%s(pack)" % LISTS[typ]['COMMANDS']['ADD'] )
            else:
                try:
                    if typ in ['TODO','CALENDAR']: exec( "self.sm.%s(pack)" % LISTS[typ]['COMMANDS']['SET'] )
                    elif typ in ['SMS']: exec( "self.sm.%s(Folder=0, pack)" % LISTS[typ]['COMMANDS']['SET'] )
                    else: exec( "self.sm.%s(pack)" % LISTS[typ]['COMMANDS']['SET'] )
                except (gammu.ERR_NOTSUPPORTED, gammu.ERR_NOTIMPLEMENTED):
                    if typ in ['TODO','CALENDAR']: exec( "self.sm.%s(Location = data['Location'])" % LISTS[typ]['COMMANDS']['DEL'] )
                    elif typ in ['SMS']: exec( "self.sm.%s(Folder=0, Location = data['Location'])" % LISTS[typ]['COMMANDS']['DEL'] )
                    else: exec( "self.sm.%s(Type=data['Type'], Location = data['Location'])" % LISTS[typ]['COMMANDS']['DEL'] )
                    time.sleep(0.3)
                    if typ in ['TODO','CALENDAR']: exec( "self.sm.%s(pack)" % LISTS[typ]['COMMANDS']['ADD'] )
                    elif typ in ['SMS']: exec( "self.sm.%s(Folder=0, pack)" % LISTS[typ]['COMMANDS']['ADD'] )
                    else: exec( "self.sm.%s(pack)" % LISTS[typ]['COMMANDS']['ADD'] )



            # Add data
            """try:
                if data['Location'] == 0:
                    if typ in ['TODO','CALENDAR']: exec( "self.sm.%s(pack)" % LISTS[typ]['COMMANDS']['ADD'] )
                    elif typ in ['SMS']: exec( "self.sm.%s(Folder=0, pack)" % LISTS[typ]['COMMANDS']['ADD'] )
                    else: exec( "self.sm.%s(typ, pack)" % LISTS[typ]['COMMANDS']['ADD'] )
                else:
                    try:
                        if typ in ['TODO','CALENDAR']: exec( "self.sm.%s(pack)" % LISTS[typ]['COMMANDS']['SET'] )
                        elif typ in ['SMS']: exec( "self.sm.%s(Folder=0, pack)" % LISTS[typ]['COMMANDS']['SET'] )
                        else: exec( "self.sm.%s(typ, pack)" % LISTS[typ]['COMMANDS']['SET'] )
                    except (gammu.ERR_NOTSUPPORTED, gammu.ERR_NOTIMPLEMENTED):
                        if typ in ['TODO','CALENDAR']: exec( "self.sm.%s(Location = data['Location'])" % LISTS[typ]['COMMANDS']['DEL'] )
                        elif typ in ['SMS']: exec( "self.sm.%s(Folder=0, Location = data['Location'])" % LISTS[typ]['COMMANDS']['DEL'] )
                        else: exec( "self.sm.%s(Type=typ, Location = data['Location'])" % LISTS[typ]['COMMANDS']['DEL'] )
                        time.sleep(0.3)
                        if typ in ['TODO','CALENDAR']: exec( "self.sm.%s(pack)" % LISTS[typ]['COMMANDS']['ADD'] )
                        elif typ in ['SMS']: exec( "self.sm.%s(Folder=0, pack)" % LISTS[typ]['COMMANDS']['ADD'] )
                        else: exec( "self.sm.%s(typ, pack)" % LISTS[typ]['COMMANDS']['ADD'] )
            except Exception, E:
                print E
                self.box_error( "Write error" )
                self.status.set_text( "Write error" )
                return"""

        # Refresh list
        self.read_data( data['Type'] )


    ###################################################################
    #
    #   Clear a part of phone data
    #

    def clear_data(self, w=None, types=[]):

        if not self.box_sure( _("You are going to delete all data of %s. Are you sure?") % types ): return

        for typ in types:

            # Is the phone connected?
            if not self.sm:
                if not self.connect(): return

            if typ in ('ME', 'SM', 'ON', 'DC', 'RC', 'MC', 'MT', 'FD', 'VM'): self.sm.DeleteAllMemory(typ)
            elif typ == 'MEMO': self.sm.DeleteAllToDo()
            elif typ == 'MEETING': self.sm.DeleteAllCalendar()

            time.sleep(0.3)
            self.read_all()


    ###################################################################
    #
    #   Export and import
    #

    def db_import(self, *args):

        self.box_future()
        return

        # Is the phone connected?
        if not self.sm:
            if not self.connect(): return

    def db_export(self, *args):

        self.box_future()
        return

        # Is the phone connected?
        if not self.sm:
            if not self.connect(): return


    ###################################################################
    #
    #   Config file managment
    #

    def setup_load(self):

        self._cfg = DEF_CFG

        try:
            home = os.getenv('USERPROFILE') or os.getenv('HOME')
            o=open('%s/.pammurc' % home,'r')
            s = o.read()
            o.close()

            for line in s.split('\n'):
                line = line.strip()
                if line != '':
                    if (line[0] != '#') and (line.find('=') != -1):
                        code = line.split('=', 2)
                        if code[1] == "None": self._cfg[code[0]] = None
                        elif code[1][0] in ("'",'"'): self._cfg[code[0]] = code[1].strip("'")
                        else: self._cfg[code[0]] = int(code[1])
        except:
            print _("Wrong setup file...")


    def setup_save(self):

        self._cfg = DEF_CFG

        home = os.getenv('USERPROFILE') or os.getenv('HOME')
        f=open('%s/.pammurc' % home,'w+')
        f.write("# Pammu config file\n\n")
        for val in self._cfg:
            if self._cfg[val].__class__ == None.__class__: f.write("%s=None\n" % val)
            elif self._cfg[val].__class__ == int: f.write("%s=%d\n" % (val, self._cfg[val]))
            else: f.write("%s='%s'\n" % (val, self._cfg[val]))
        f.close()


    ###################################################################
    #
    #   Call an URL
    #

    def url_open(self, w=None, url=__helpurl__):

        webbrowser.open( url )


    ###################################################################
    #
    #   GTK dialog boxes
    #

    def box_about(self, *arg):

        dia = gtk.Dialog( _("About"), self.window.get_toplevel(), gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT, (gtk.STOCK_CLOSE, gtk.RESPONSE_CLOSE))
        hbox = gtk.HBox()
        dia.vbox.pack_start(hbox, False, False, 4)
        image = gtk.Image()
        image.set_from_pixbuf(PB['MOBILE'])
        hbox.pack_start(image, False, False, 4)
        vbox = gtk.VBox()
        hbox.pack_start(vbox, False, False, 4)
        label = gtk.Label( __fullname__ )
        label.modify_font(pango.FontDescription('lucida sans unicode 20'))
        vbox.pack_start(label, False, False, 8)
        vbox.pack_start(gtk.Label("%s" % __version__), False, False, 4)
        separator = gtk.HSeparator()
        vbox.pack_start(separator, False, False, 0)
        vbox.pack_start(gtk.Label("%s" % __about__), False, False, 4)
        dia.show_all()
        result = dia.run()
        dia.destroy()

    def box_future(self, *args):

        self.box_error( _("This function not implemented yet.") )

    def box_error(self, msg):

        dia = gtk.Dialog( _("Error"), self.window.get_toplevel(), gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT, (gtk.STOCK_CLOSE, gtk.RESPONSE_CLOSE))
        label = gtk.Label(msg)
        label.set_property('xpad', 12)
        dia.vbox.pack_start(label, False, False, 8)
        dia.show_all()
        result = dia.run()
        dia.destroy()

    def box_sure(self, msg):

        dia = gtk.Dialog( _("Warning"), self.window.get_toplevel(), gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT, (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL, gtk.STOCK_OK, gtk.RESPONSE_OK))
        label = gtk.Label(msg)
        label.set_property('xpad', 12)
        dia.vbox.pack_start(label, False, False, 8)
        dia.show_all()
        result = dia.run()
        dia.destroy()
        if result == gtk.RESPONSE_OK: return True
        return False

    def box_setup(self, *args):

        # Dialog window
        dia = gtk.Dialog( _("Preferences"), self.window.get_toplevel(), gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
            (gtk.STOCK_APPLY, gtk.RESPONSE_APPLY, str( _("Save") ), 998, gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL))
        hbox = gtk.HBox()
        dia.vbox.pack_start(hbox, False, False, 4)
        image = gtk.Image()
        image.set_from_pixbuf(PB['MOBILE'])
        hbox.pack_start(image, False, False, 4)
        vbox = gtk.VBox()
        hbox.pack_start(vbox, False, False, 4)

        # Connection
        label = gtk.Label( _("Connection type:") )
        label.set_alignment(0.0, 0.5)
        vbox.pack_start(label, True, False, 2)
        conn_list = gtk.combo_box_new_text()
        vbox.pack_start(conn_list, False, False, 2)
        for txt in CONNECTION_TYPES: conn_list.append_text( txt )
        for x in range( len( conn_list.get_model() ) ):
            if conn_list.get_model()[x][0] == self._cfg['Connection']:
                conn_list.set_active(x)

        # Model
        label = gtk.Label( _("Model:") )
        label.set_alignment(0.0, 0.5)
        vbox.pack_start(label, True, False, 2)
        model_list = gtk.combo_box_new_text()
        vbox.pack_start(model_list, False, False, 2)
        for txt in CONNECTION_MODELS: model_list.append_text( txt )
        if self._cfg['Model'] == '':
            model_list.set_active(0)
        else:
            for x in range( len( model_list.get_model() ) ):
                if model_list.get_model()[x][0] == self._cfg['Model']:
                    model_list.set_active(x)

        # Port
        label = gtk.Label( _("Port:") )
        label.set_alignment(0.0, 0.5)
        vbox.pack_start(label, True, False, 2)
        port_list = gtk.combo_box_entry_new_text()
        vbox.pack_start(port_list, False, False, 2)
        if gtk.sys.platform == 'win32':
            for txt in CONNECTION_PORTS_WIN: port_list.append_text( txt )
        else:
            for txt in CONNECTION_PORTS_LIN: port_list.append_text( txt )
        for x in range( len( port_list.get_model() ) ):
            if port_list.get_model()[x][0] == self._cfg['Device']: port_list.set_active(x)
        if port_list.get_active() == -1:
            port_list.insert_text(0, self._cfg['Device'])
            port_list.set_active(0)

        # Show
        dia.show_all()
        result = dia.run()

        # Ok
        if result in (gtk.RESPONSE_APPLY, 998):
            active = conn_list.get_active()
            if active >= 0: self._cfg['Connection'] = conn_list.get_model()[active][0]
            active = model_list.get_active()
            if active >= 0: self._cfg['Model'] = model_list.get_model()[active][0]
            self._cfg['Device'] = port_list.child.get_text()

            # Save
            if result == 998: self.setup_save()

        # Exit
        dia.destroy()
        self.clear_info()


    def box_dialog(self, data, *args):

        # Create field data from parameters
        boxx = gtk.VBox()
        field = {}
        ret = {}
        for line in data:
            ret[ line[0] ] = line[1]

            # Text field
            if line[2] == -1:
                continue

            if line[2] in (0, 1):
                if line[1] == '_NOW_': line[1] = datetime.datetime.now().strftime("%d/%m/%Y %H:%M")
                field[ line[0] ] = gtk.Entry()
                field[ line[0] ].set_max_length(50)
                field[ line[0] ].set_text( str(line[1]) )
                field[ line[0] ].set_editable( line[2] == 1)

            # Combo box
            else:
                field[ line[0] ] = gtk.combo_box_new_text()
                for txt in line[2]: field[ line[0] ].append_text( txt )
                for x in range( len( field[ line[0] ].get_model() ) ):
                    if field[ line[0] ].get_model()[x][0] == line[1]:
                        field[ line[0] ].set_active(x)

            # Show field
            label = gtk.Label( "%s:" % line[0] )
            label.set_alignment(0.0, 0.5)
            box = gtk.HBox()
            box.pack_start(label, False, False, 2)
            box.pack_start(field[ line[0] ], True, True, 2)
            boxx.pack_start(box, False, False, 2)

        # Show form
        if ret['Location'] != '0':
            dia = gtk.Dialog( _("Upload"), self.window.get_toplevel(), gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
                (gtk.STOCK_OK, gtk.RESPONSE_OK, gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL, str( _("Delete") ), 999))
        else:
            dia = gtk.Dialog( _("Upload"), self.window.get_toplevel(), gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
                (gtk.STOCK_OK, gtk.RESPONSE_OK, gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL))

        dia.vbox.pack_start(boxx, False, False, 2)
        dia.show_all()
        result = dia.run()
        dia.destroy()

        # Delete
        if result == 999:
            return RET_DELETE, ret

        # Ok
        if result == gtk.RESPONSE_OK:

            # Read answers
            for line in data:

                # Constant
                if line[2] == -1:continue

                # Text field
                if line[2] in (0, 1): ret[ line[0] ] = field[ line[0] ].get_text()

                # Combo box
                else:
                    active = field[ line[0] ].get_active()
                    if active >= 0: ret[ line[0] ] = field[ line[0] ].get_model()[active][0]

            return RET_OK, ret

        return RET_CANCEL, None


    ###################################################################
    #
    #   Main
    #

    def main(self):

        gtk.main()
        return 0


if __name__ == "__main__":

    # Locale
    try:
        #t = gettext.translation('pammu', '/home/msv/myProjects/Pammu/locale', languages=['hu'])
        t = gettext.translation('pammu', './locale')
        _ = t.ugettext
        t.install()
    except:
        _ = str

    # Process arguments
    for opt in os.sys.argv[1:]:

        # POT file creation
        if opt == '--pot':

            head = """msgid ""\nmsgstr ""\n"Project-Id-Version: Pammu 1.0\\n"\n"POT-Creation-Date: 2009\\n"\n"Last-Translator: Marton S. Viktor <msv@titok.info>\\n"\n"Language-Team: Pammu\\n"\n"MIME-Version: 1.0\\n"\n"Content-Type: text/plain; charset=utf-8\\n"\n"Content-Transfer-Encoding: 8bit\\n"\n"X-Poedit-SourceCharset: utf-8\\n"\n\n"""
            po = """msgid ""\nmsgstr ""\n"Project-Id-Version: Pammu 1.0\\n"\n"POT-Creation-Date: 2009\\n"\n"PO-Revision-Date: \\n"\n"Last-Translator: Marton S. Viktor <msv@titok.info>\\n"\n"Language-Team: Pammu <msv@titok.info>\\n"\n"MIME-Version: 1.0\\n"\n"Content-Type: text/plain; charset=utf-8\\n"\n"Content-Transfer-Encoding: 8bit\\n"\n"X-Poedit-Language: Hungarian\\n"\n"X-Poedit-Country: HUNGARY\\n"\n"X-Poedit-SourceCharset: utf-8\\n"\n\n"""

            old, val, tmp, store = {}, '', '', 0

            try:
                o=open('pammu.po','r')
                s = o.read()
                o.close()

                for x in xrange(len(s)-4):
                    if store == 1: tmp += s[x]
                    elif store == 2: val += s[x]

                    if s[x-6:x+1] == 'msgid "':
                        store = 1
                        tmp, val = '', ''
                    if s[x-7:x+1] == 'msgstr "':
                        store = 2
                        val = ''
                    if (s[x+1:x+3] == '"\n'):
                        if (tmp != "") and (val != ""):
                            old[tmp] = val
                            tmp = ''
                        val, store = '', 0
            except:
                pass

            ret, ret2, tmp, rep = po, head, '', {}

            o=open('pammu.py','r')
            s = o.read()
            o.close()

            for x in xrange(len(s)-4):
                if tmp != '': tmp += s[x+1]
                if s[x:x+3] == '_("': tmp = 'msgid '
                if (s[x+1:x+3] == '")') and (tmp != ''):
                    if not tmp in rep:
                        if tmp[7:-1] in old: ret += tmp + '\nmsgstr "%s"\n\n' % old[tmp[7:-1]]
                        else: ret += tmp + '\nmsgstr ""\n\n'
                        ret2 += tmp + '\nmsgstr ""\n\n'
                        rep[tmp] = 'yes'
                    tmp = ''

            f=open('pammu.pot','w+')
            f.write( ret2 )
            f.close()

            f=open('pammu.po','w+')
            f.write( ret )
            f.close()

            os.sys.exit(0)
        else:
            print _("Unidentified parameter")

    # Start
    Pammu().main()

#END
